package require Dayswig_tcl
package provide libdaytcl 1.0

#
# a simple canvas depiction library for daytcl.
#

#
# initialize drawing library
#
proc dl_beginscreen {} {
    upvar #0 dl_depict..depiction depiction
    $depiction(window) delete all
}
proc dl_endscreen {} {
    upvar #0 dl_depict..depiction depiction
    # fit the image drawn to the window
    if {[catch {
	set bbox [$depiction(window) bbox line]
	if {"$bbox" == {}} {
	    set bbox [$depiction(window) bbox all]
	}
	foreach {x0 y0 xn yn} $bbox { break }
	set bw [expr $xn-$x0];		# bounding box width
	set bh [expr $yn-$y0];		# bounding box height
	set bx [expr $x0+$bw/2];	# bounding box center x
	set by [expr $y0+$bh/2];	# bounding box center y
	set ww [winfo width $depiction(window)];	# window width
	set wh [winfo height $depiction(window)];	# window height
	set wx [expr $ww/2];		# window center x
	set wy [expr $wh/2];		# window center y
	set dx [expr $wx-$bx];		# translate x to center window
	set dy [expr $wy-$by];		# translate y to center window
	set sx [expr double($ww)/$bw];	# width full scale
	set sy [expr double($wh)/$bh];	# height full scale
	#puts "bbox $x0 $y0 $xn $yn, size $bw by $bh, center $bx $by"
	#puts "window size $ww by $wh, center $wx $wy"
	#puts "move $dx $dy, scale $sx or $sy"
	$depiction(window) move all $dx $dy
	if {$sx < $sy} {
	    $depiction(window) scale all $wx $wy $sx $sx
	} else {
	    $depiction(window) scale all $wx $wy $sy $sy
	}
    } error]} {
	puts stderr $error
    }
}
proc dl_flush {} {
    upvar #0 dl_depict..depiction depiction
}
proc dl_setcellcount {args} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_cellcount) $args
    set depiction(dl_cellrows) 1
    set depiction(dl_cellcols) $args
}
proc dl_setcellrc {r c} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_cellrows) $r
    set depiction(dl_cellcols) $c
    set depiction(dl_cellcount) [expr $r * $c]
}
proc dl_cellcount {} {
    upvar #0 dl_depict..depiction depiction
    return $depiction(dl_cellcount)
}
proc dl_cellrows {} {
    upvar #0 dl_depict..depiction depiction
    return $depiction(dl_cellrows)
}
proc dl_cellcols {} {
    upvar #0 dl_depict..depiction depiction
    return $depiction(dl_cellcols)
}
proc dl_setcell {args} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_cell) $args
}
proc dl_cell {} {
    upvar #0 dl_depict..depiction depiction
    return $depiction(dl_cell)
}
proc dl_setga {ga} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_ga) $ga
    if {[catch {du_ga_color $ga} depiction(color)]} {
	set depiction(color) black
    }
}
proc dl_ga {} {
    upvar #0 dl_depict..depiction depiction
    return $depiction(dl_ga)
}
proc dl_colormode {} {
    upvar #0 dl_depict..depiction depiction
    return $depiction(dl_colormode)
}
proc dl_setlinewidth {w} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_linewidth) $w
}
proc dl_setlinestyle {s} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_linestyle) $s
}
proc dl_setpixels {x y} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_pixels) $args
}
proc dl_pixels {} {
    upvar #0 dl_depict..depiction depiction
    return $depiction(dl_pixels)
}
proc dl_setbounds {x y width height} {
    upvar #0 dl_depict..depiction depiction
    set depiction(x) $x
    set depiction(y) $y
    set depiction(width) $width
    set depiction(height) $height
}
proc dl_fitbounds {x0 y0 xn yn} {
    upvar #0 dl_depict..depiction depiction
    set depiction(x) $x0
    set depiction(y) $y0
    set depiction(width) [expr $xn-$x0]
    set depiction(height) [expr $yn-$y0]
}
proc dl_fixbounds {fixed} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_fixbounds) $fixed
}
proc dl_bounds {} {
    upvar #0 dl_depict..depiction depiction
    return [list $depiction(x) $depiction(y) $depiction(width) $depiction(height)]
}
proc dl_setaspect {a} {
    upvar #0 dl_depict..depiction depiction
    set depiction(dl_aspect) $a
}
proc dl_paspect {} {
    return $depiction(dl_aspect)
}
proc dl_moveto {x y} {
    upvar #0 dl_depict..depiction depiction
    set depiction(cur-x) $x
    set depiction(cur-y) $y
}
proc dl_drawto {x y} {
    upvar #0 dl_depict..depiction depiction
    $depiction(window) create line $depiction(cur-x) $depiction(cur-y) $x $y -fill $depiction(color) \
	-tags [concat $depiction(tags) [list line]]
    set depiction(cur-x) $x
    set depiction(cur-y) $y
}
proc dl_drawbox {x0 y0 xn yn} {
    upvar #0 dl_depict..depiction depiction
    $depiction(window) create rectangle $x0 $y0 $xn $yn -outline $depiction(color) \
	-tags [concat $depiction(tags) [list box]]
}
proc dl_drawoval {x0 y0 xn yn} {
    upvar #0 dl_depict..depiction depiction
    $depiction(window) create oval $x0 $y0 $xn $yn -outline $depiction(color) \
	-tags [concat $depiction(tags) [list oval]]

}
proc dl_labelbounds {text sizes super tags x y size angle} {
    upvar #0 dl_depict..depiction depiction
    return [list [expr $x-$size/2] [expr $y-$size/2] [expr $x+$size/2] [expr $y+$size/2]]
}
proc dl_drawlabel {text sizes super tags x y size angle} {
    upvar #0 dl_depict..depiction depiction
    if {$depiction(ovals)} {
	$depiction(window) create oval [expr $x-$size/2] [expr $y-$size/2] [expr $x+$size/2] [expr $y+$size/2] -fill $depiction(color) \
	    -tags [concat $depiction(tags) [list oval]]
    } else {
	$depiction(window) create text $x $y -text $text -fill $depiction(color) \
	    -tags [concat $depiction(tags) [list label]]
    }
}
proc dl_fitlabel {text sizes super tags x y size angle bounds} {
    upvar #0 dl_depict..depiction depiction
}    
proc dl_stdcolor_count {} {
    upvar #0 dl_depict..depiction depiction
    return 256
}
proc dl_stdcolor_init {args} {
    upvar #0 dl_depict..depiction depiction
    return 1
}
proc dl_stdcolor_name {i} {
    upvar #0 dl_depict..depiction depiction
    return stub
}
proc dl_stdcolor_def {i r g b} {
    upvar #0 dl_depict..depiction depiction
    return 1
}
proc dl_stdcolor_act {i r g b} {
    upvar #0 dl_depict..depiction depiction
    return 1
}
proc dl_stdcolor_index {name} {
    upvar #0 dl_depict..depiction depiction
    return 1
}
proc dl_stdcolor_pixel {i} {
    upvar #0 dl_depict..depiction depiction
    return 1
}


#
# call this procedure, instead of dt_depict directly, to draw a
# depiction into a Tk canvas.
#
proc dl_depict {w depict {tags {}}} {
    # bind data
    upvar #0 dl_depict..depiction depiction
    
    # initialize data
    catch {unset depiction}
    array set depiction [list \
			     dl_cellcount 1 \
			     dl_cellrows 1 \
			     dl_cellcols 1 \
			     dl_cell 1\
			     dl_ga [DL_GA_DEFAULT] \
			     dl_colormode [DL_COLORMODE_MONOCHROME] \
			     dl_linewidth [DL_LINEWIDTH_DEFAULT] \
			     dl_linestyle [DL_LINESTYLE_DEFAULT] \
			     dl_pixels 0 \
			     dl_aspect 1 \
			     ovals 0 \
			     color black \
			     linewidth 0 \
			     linestyle 0 \
			     tags $tags \
			    ]
    
    #
    # draw the depiction
    #
    set depiction(window) $w
    dl_beginscreen
    dt_depict $depict
    dl_endscreen
    
}
