package require Dayswig_tcl
package provide libdaytcl 1.0

#
#  du_coloratoms.tcl -- give standard graphic attributes to atoms in depiction
#
#  This routine applies standard drawing library attributes for the
#  appropriate element to atoms in the given depiction.  Unless set
#  otherwise, bond-ends will inherit ga's from their end atoms.
#
#  This does *not* set ga's for the depiction labels.
#
#

#
#  du_coloratoms() -- apply element colors to atoms, default to bonds & cycles
#


proc du_coloratoms {depict}  {
    # Return unhappy if molecule (or depiction) is the NULL_OB.
    set mol [dt_base $depict];
    if {"$mol" == "[NULL_OB]"} {
	return 0;
    }

    # Set ga's for atoms based on atomic number.

    foreach atom [du_atoms $mol] {
	dt_setga $depict $atom [expr 100+[dt_number $atom]];
    }
	
    # Set default ga's for bonds.

    foreach bond [du_bonds $mol] {
	dt_setga $depict $bond [DL_GA_DEFAULT];
    }

    # Set default ga's for cycles.

    foreach cycle [du_cycles $mol] {
	dt_setga $depict $cycle [DL_GA_DEFAULT];
    }

    # Return happy.

    return 1;
}
