package require Dayswig_tcl
package provide libdaytcl 1.0

########################################################################
#  du_define_attrib() -- interpret a SMARTS into a named vbind
#  Taken form daylight contrib.
#
#  This interprets the SMARTS into a pattern which can be used just as if
#  du_smartin() was called, and also associates the pattern with a `vbind'
#  which can be used as an attribute in subsequent SMARTS specifications.
#  E.g., if the first argument is "name", the expression $name would match
#  atoms which have the same environment as the first atom in `smarts'.
#
#  This routine also associates vbind with the pattern for convenience
#  in deallocation (the calling program need only keep track of pat).
#  Note: the reverse association is provided by dt_getval(vbind).
#


proc du_define_attrib {name smarts} {
   
    # Interpret a SMARTS into a pattern; warn on stderr if unable.
    if {[catch {dt_smartin $smarts} pat]} {
	error "Can't interpret SMARTS: $smarts\n$pat";
    }
    if {"$pat" == "[NULL_OB]"} {
	error "Can't interpret SMARTS: $smarts";
    }

    # Create a vector binding by given name
    set vbind [dt_alloc_vbind $name];

    # Associate pattern with it
    dt_setval $vbind $pat;

    # Connect vbind to pattern, for convienience in deallocation.
    dt_setadjunct $pat $vbind;

    # Return pattern.
    return $pat;
}

