package require Dayswig_tcl
package provide libdaytcl 1.0

#
# A canvas based molecular depiction which doesn't employ the daylight
# dl_* library and dt_depict.
#

proc du_depict {c depict {tags {}}} {
    # find the molecule
    set mol [dt_base $depict]

    # process depiction attributes
    # compressed - chains of like atoms are suppressed
    set compressed [dt_compressed $depict]

    # frame surrounding molecule
    set frame [dt_frame $depict]
    if {[catch {du_ga_color [dt_framega $depict]} framega]} {
	set framega black;
    }

    # isomeric - draw bonds to display isomeric structures
    set isomeric [dt_isomeric $depict]

    # first label for molecule
    set label1 [dt_label1 $depict $mol]
    if {[catch {du_ga_color [dt_label1ga $depict $mol]} label1ga]} {
	set label1ga black;
    }

    # second label for molecule
    set label2 [dt_label2 $depict $mol]
    if {[catch {du_ga_color [dt_label2ga $depict $mol]} label2ga]} {
	set label2ga black;
    }

    # orient - orientation hints
    set orient [dt_orient $depict]

    # schematic - normal carbons suppressed, no circle in aromatic rings
    set schematic [dt_schematic $depict]

    # locate the atoms
    foreach atom [du_atoms $mol] {
	set sxyz [dt_getcoord $depict $atom]
	if {[lindex $sxyz 0] == 1} {
	    set xy($atom) [lrange $sxyz 1 2]
	} else {
	    error "no coordinate assigned for atom $atom"
	}
	if {[catch {du_ga_color [dt_ga $depict $atom]} ga($atom)]} {
	    set ga($atom) black;
	}
    }
    # draw the bonds
    foreach bond [du_bonds $mol] {
	#
	# daylight depictions show bonds sharing the colors of their
	# atoms, but there isn't any way for a single graphic
	# attribute to represent that, ie what daylight does in the
	# pictures it draws cannot be done with the depiction toolkit.
	#
	if {[catch {du_ga_color [dt_ga $depict $bond]} ga($bond)]} {
	    set ga($bond) black;
	}

	set atoms [du_atoms $bond]

	set a1 [lindex $atoms 0]
	set a2 [lindex $atoms 1]

	set bs1 [dt_bondstyle $depict $a1 $bond]
	set bs2 [dt_bondstyle $depict $a2 $bond]

	set tuple [list [du_depict..bondmap [dt_bondorder $bond]] [du_depict..edgemap $bs1] [du_depict..edgemap $bs2]]

	switch -exact $tuple {
	    {none SIMPLE SIMPLE} {
		;
	    }
	    {unknown SIMPLE SIMPLE} -
	    {single SIMPLE SIMPLE} -
	    {aromat SIMPLE SIMPLE} -
	    {wild SIMPLE SIMPLE} {
		foreach {x1 y1 x2 y2} "$xy($a1) $xy($a2)" break
		$c create line $x1 $y1 $x2 $y2 -fill $ga($bond)\
		    -tags [concat $tags {bond}]
	    }
	    {single TRI|TRI_IN TRI|TRI_OUT} - 
	    {single TRI|TRI_IN|HASH TRI|TRI_OUT|HASH} {
		set o [du_depict..bondperp $xy($a1) $xy($a2)]
		foreach {x1 y1 x2 y2 x3 y3} "[du_depict..vadds $xy($a1) 0.06 $o] [du_depict..vadds $xy($a1) -0.06 $o] $xy($a2)" break
		$c create polygon $x1 $y1 $x2 $y2 $x3 $y3 -fill $ga($bond)\
		    -tags [concat $tags {bond}]
	    }
	    {single TRI|TRI_OUT TRI|TRI_IN} -
	    {single TRI|TRI_OUT|HASH TRI|TRI_IN|HASH} {
		set o [du_depict..bondperp $xy($a1) $xy($a2)]
		foreach {x1 y1 x2 y2 x3 y3} "$xy($a1) [du_depict..vadds $xy($a2) 0.06 $o] [du_depict..vadds $xy($a2) -0.06 $o]" break
		$c create polygon $x1 $y1 $x2 $y2 $x3 $y3 -fill $ga($bond)\
		    -tags [concat $tags {bond}]
	    }
	    {double SIMPLE SIMPLE} {
		set o [du_depict..bondperp $xy($a1) $xy($a2)]
		foreach s {0.06 -0.06} {
		    foreach {x1 y1 x2 y2} "[du_depict..vadds $xy($a1) $s $o] [du_depict..vadds $xy($a2) $s $o]" break
		    $c create line $x1 $y1 $x2 $y2 -fill $ga($bond)\
			-tags [concat $tags {bond}]
		}
	    }
	    {triple SIMPLE SIMPLE} {
		set o [du_depict..bondperp $xy($a1) $xy($a2)]
		foreach s {0.1 0.00 -0.1} {
		    foreach {x1 y1 x2 y2} "[du_depict..vadds $xy($a1) $s $o] [du_depict..vadds $xy($a2) $s $o]" break
		    $c create line $x1 $y1 $x2 $y2 -fill $ga($bond)\
			-tags [concat $tags {bond}]
		}
	    }
	    default {
		error "uncaught bond tuple $tuple";
	    }
	}
    }
    # label the atoms
    foreach atom [du_atoms $mol] {
	foreach {x y} $xy($atom) break
	set label($atom) [$c create text $x $y -text [dt_symbol $atom] -fill $ga($atom) \
			      -tags [concat $tags {atom label}]]
    }
    # fit the image drawn to the window
    foreach bb [list [$c bbox bond] [$c bbox all]] {
	if {[llength $bb] == 4} {
	    foreach {x0 y0 xn yn} $bb break
	    set bw [expr $xn-$x0];		# bounding box width
	    set bh [expr $yn-$y0];		# bounding box height
	    set bx [expr $x0+$bw/2];		# bounding box center x
	    set by [expr $y0+$bh/2];		# bounding box center y
	    set ww [winfo width $c];		# window width
	    set wh [winfo height $c];		# window height
	    set wx [expr $ww/2];		# window center x
	    set wy [expr $wh/2];		# window center y
	    set dx [expr $wx-$bx];		# translate x to center window
	    set dy [expr $wy-$by];		# translate y to center window
	    set sx [expr double($ww)/$bw];	# width full scale
	    set sy [expr double($wh)/$bh];	# height full scale
	    $c move all $dx $dy;
	    if {$sx < $sy} {
		$c scale all $wx $wy $sx $sx
	    } else {
		$c scale all $wx $wy $sy $sy
	    }
	    # put boxes under each atom label to hide the bonds
	    foreach atom [du_atoms $mol] {
		foreach {x1 y1 xn yn} [$c bbox $label($atom)] break
		set box [$c create rectangle $x1 $y1 $xn $yn -fill white -outline white -tags [concat $tags {atom box}]]
	    }
	    $c raise label
	    break
	}
    }
}

# unpack packed bondstyles into text
proc du_depict..edgemap {bs} {
    # map bondstyles into text
    upvar \#0 du_depict..edgemap edgemap
    array set edgemap [list \
			   [DX_EDGE_SIMPLE] SIMPLE \
			   [DX_EDGE_TEE] TEE \
			   [DX_EDGE_TEE_IN] TEE_IN \
			   [DX_EDGE_TEE_OUT] TEE_OUT \
			   [DX_EDGE_TRI] TRI \
			   [DX_EDGE_TRI_IN] TRI_IN \
			   [DX_EDGE_TRI_OUT] TRI_OUT \
			   [DX_EDGE_HASH] HASH \
			   [DX_EDGE_DATIVE] DATIVE \
			  ]

    proc du_depict..edgemap {bs} {
	upvar \#0 du_depict..edgemap edgemap
	if {[info exists edgemap($bs)]} {
	    return $edgemap($bs)
	}
	for {set i 1} {$bs != 0} {set i [expr $i<<1]} {
	    if {$bs & $i} {
		lappend map $edgemap($i)
		set bs [expr $bs ^ $i]
	    }
	}
	return [join $map |]
    }
    
    return [du_depict..edgemap $bs];
}

# unpack a bondorder into text
proc du_depict..bondmap {bo} {
    # map bondorders into text
    upvar \#0 du_depict..bondmap bondmap
    array set du_depict..bondmap [list \
				  [DX_BTY_UNKNOWN] unknown \
				  [DX_BTY_SINGLE] single \
				  [DX_BTY_DOUBLE] double \
				  [DX_BTY_TRIPLE] triple \
				  [DX_BTY_AROMAT] aromat \
				  [DX_BTY_WILD] wild \
				  [DX_BTY_NONE] none \
				 ]

    proc du_depict..bondmap {bo} {
	upvar \#0 du_depict..bondmap bondmap
	return $bondmap($bo)
    }

    return [du_depict..bondmap $bo];
}


# return a unit perpendicular vector to the bond from xy1 to xy2
proc du_depict..bondperp {xy1 xy2} {
    set len2 0
    foreach c1 $xy1 c2 $xy2 {
	set c12 [expr $c1-$c2]
	lappend v $c12;
	append len2 +$c12*$c12
    }
    set len [expr sqrt($len2)]
    set v [list [expr -[lindex $v 1]/$len] [expr [lindex $v 0]/$len]]
    #puts "bondperp {$xy1 $xy2} -> {$v}"
    return $v;
}

# add a scaled copy of a vector to a point
proc du_depict..vadds {xy s v} {
    foreach c1 $xy c2 $v {
	lappend u [expr $c1+$s*$c2]
    }
    #puts "vadds {$xy} $s {$v} -> {$u}"
    return $u;
}