package require Dayswig_tcl
package provide libdaytcl 1.0

#
#  du_mf.c
#
#  This creates a cannonical molecular formula for an atom-containing object
#  (typically used for molecules).  The molecular formula is returned as a
#  Tcl string.
#
#  du_mf() -- return combined molecular formula of object as a Tcl string.
#
#  The molecular formula is printed in the order C, H, then alphabetically
#  by atomic symbol (this order is coded in du_mf..lsort).
#
#  Although usually used with objects of TYP_MOLECULE, this works for any
#  atom-containing object (i.e. molecules, atoms, bonds, cycles, substructs,
#  paths, streams, and sequences).
#
#  Standard atomic symbols are assumed for first 105 elements.  (Symbols used
#  by the Daylight Toolkit for elements 100-105 are: Fm, Md, No, Lr, Rf, Ha.)
#


proc du_mf..lsort {syms} {
    set nsyms {};
    foreach s {C H} {
	if {[set i [lsearch $syms $s]] >= 0} {
	    lappend nsyms $s;
	    set syms [lreplace $syms $i $i];
	}
    }
    return [concat $nsyms [lsort -ascii $syms]];
}

proc du_mf {ob} {

    # Accumulate element frequencies

    set frequency(H) 0;
    foreach atom [du_stream_to_list [dt_stream $ob [TYP_ATOM]]] {
	set sym [dt_symbol $atom];
	if { ! [info exists frequency($sym)]} {
	    set frequency($sym) 0;
	}
	incr frequency($sym);
	incr frequency(H) [dt_imp_hcount $atom];
    }

    # Return molecular formula as the string object form of elf.
    set formula {};
    foreach sym [du_mf..lsort [array names frequency]] {
	if {$frequency($sym) > 0} {
	    append formula $sym;
	    if {$frequency($sym) > 1} {
		append formula $frequency($sym);
	    }
	}
    }

    # Return molecular formula as a string

    return $formula
}
