package require Dayswig_tcl
package provide libdaytcl 1.0

#
# FILE: du_normal_mass.c
#
# SYNOPSIS:
#
#   int du_normal_mass(dt_Handle atom)
#
#	Returns the mass (as an integer) of the most common isotope, or if
#	the element is not stable, returns the atomic mass of the most
#	stable isotope.
#
#

#
#  nomass -- normal atomic mass data
#
#  If naturally occurring, for the most common isotope
#  If not naturally occurring, for the most stable known isotope
#  Reference: CRC Handbook of Chemistry and Physics, 60th Ed.
#

set du_normal_mass..nomass { 0
    1   4   7   9  11  12  14  16  19  20
    23  24  27  28  31  32  35  40  39  40
    45  48  51  52  55  56  59  58  63  64
    69  74  75  80  79  84  85  88  89  90
    93  98  97 102 103 106 107 114 115 120
    121 130 127 132 133 138 139 140 141 142
    145 152 153 158 159 164 165 166 169 174
    175 180 181 184 187 192 193 195 197 202
    205 208 209 209 210 222 223 226 227 232
    231 238 237 244 243 247 247 251 254 257
    257 255 256 260 262
};


#
#  du_normal_mass() -- return integral normal atomic mass for given atom
#
#  If naturally occurring, for the most common isotope
#  If not naturally occurring, for the most stable known isotope
#  If out-of range 1-105, returns 0.
#
#  Reference: CRC Handbook of Chemistry and Physics, 60th Ed.
#


proc du_normal_mass {atom} {
    upvar \#0 du_normal_mass..nomass nomass;

    set atno [dt_number $atom];

    # Reject out-of-bounds requests.

    if {$atno < 0 || $atno >= [llength $nomass]} {
	return 0;
    }

    # Return table value.

    return [lindex $nomass $atno];
}

