package require Dayswig_tcl
package provide libdaytcl 1.0

#
# process the daylight options data base, system options, personal
# options, environment, and command line arguments to generate an
# options database in a tcl array variable
#

proc du_options..finish-definition {} {
    upvar dy_options dy_options
    if {[info exists dy_options(current)]} {
	array set current $dy_options(current)
	if {[info exists dy_options(FLAGLIST)] && [info exists current(FLAGS)]} {
	    set match 0;
	    foreach f $current(FLAGS) {
		if {[lsearch -exact $dy_options(FLAGLIST) $f] >= 0} {
		    set match 1;
		    break;
		}
	    }
	} else {
	    set match 1;
	}
	set match 1;			# ignore whether we match or not
	if {$match} {
	    set name $current(NAME)
	    foreach a [array names current] {
		switch -exact $a {
		    NAME {
			continue;
		    }
		    VALUE {
			set dy_options($name) $current($a)
		    }
		    default {
			set dy_options($name:$a) $current($a)
		    }
		}
	    }
	} elseif {[info exists current(FLAGS)]} {
	    puts stderr "failed to match: $current(NAME) $current(FLAGS) in FLAGLIST: $dy_options(FLAGLIST)"
	}
	unset dy_options(current)
    }
}
    
proc du_options..option-definition {type name} {
    upvar dy_options dy_options
    du_options..finish-definition
    lappend dy_options(current) NAME $name TYPE $type
}

proc du_options..option-attribute {attribute value} {
    upvar dy_options dy_options
    set value [string trim $value]
    switch -exact $attribute {
	FLAGS {
	    regsub -all {, *} $value { } value
	    lappend dy_options(current) $attribute $value
	}
	ONEOF {
	    set value [split $value |]
	    lappend dy_options(current) $attribute $value
	}
	default {
	    lappend dy_options(current) $attribute $value
	}
    }
}

proc du_options..option-value {name value} {
    upvar dy_options dy_options
    if {[info exists dy_option($name)]} {
	set dy_option($name) $value;
    } else {
	set dy_option($name) $value;	# ignore whether the option is defined or not
	#puts stderr "no such option: $name = $value"
    }
}

proc du_options..dot-dat {file} {
    upvar dy_options dy_options
    global env
    upvar \#0 env(DY_ROOT) DY_ROOT
    upvar \#0 env(HOME) HOME
    set file [subst $file]
    set o [open $file]
    #puts stderr "du_options..dot-dat: $file"
    while {[gets $o line] >= 0} {
	switch -regexp -- $line {
	    {^$} -
	    {^[^\#a-zA-Z].*$} {
		continue;
	    }
	    {^\#DEFINE .*} {
		# process flags definition
		if {[regexp {^\#DEFINE +([A-Z]+) +([A-Z|]+)$} $line all name value]} {
		    switch $name {
			FLAGLIST {
			    set dy_options(FLAGLIST) {}
			    foreach f [split [string trim $value] |] {
				if {"$f" != {}} {
				    lappend dy_options(FLAGLIST) $f;
				}
			    }
			}
			MOREFLAGS {
			    foreach f [split [string trim $value] |] {
				if {"$f" != {}} {
				    lappend dy_options(FLAGLIST) $f;
				}
			    }
			}
			default {
			    puts stderr "\#define $name ..."
			}
		    }
		} else {
		    puts stderr "$file: $line"
		}
	    }
	    {^\#include .*} {
		# process another file
		set ifile [lindex $line 1]
		switch -glob $ifile {
		    *.dat {
			du_options..dot-dat $ifile
		    }
		    *.opt {
			du_options..dot-opt $ifile
		    }
		    default {
			puts stderr "$file: $line"
		    }
		}
	    }
	    {^[A-Z]+ OPTION .*} {
		# process an option definition
		du_options..option-definition  [lindex $line 0] [lindex $line 2]
	    }
	    {^TITLE:.*} -
	    {^FLAGS:.*} -
	    {^VALUE:.*} -
	    {^ONEOF:.*} -
	    {^UPPER:.*} -
	    {^LOWER:.*} {
		if {[regexp {^([A-Z]+):(.*)$} $line all attribute value]} {
		    du_options..option-attribute $attribute $value
		} else {
		    puts stderr "$file: $line"
		}
	    }
	    default {
		puts stderr "$file: $line"
	    }
	}
    }
    du_options..finish-definition
    close $o
}

proc du_options..dot-opt {file} {
    upvar dy_options dy_options
    global env
    upvar \#0 env(DY_ROOT) DY_ROOT
    upvar \#0 env(HOME) HOME
    set file [subst $file];
    if {[file exists $file] && [file readable $file]} {
	set o [open $file]
	#puts stderr "du_options..dot-opt: $file"
	set iftrue 1
	set stack {}
	while {[gets $o line] >= 0} {
	    switch -regexp -- $line {
		{^\#include .*} {
		    # process another file
		    set ifile [lindex $line 1]
		    switch -glob $ifile {
			*.dat {
			    du_options..dot-dat $ifile
			}
			*.opt {
			    du_options..dot-opt $ifile
			}
			default {
			    puts stderr "$file: $line"
			}
		    }
		}
		{^\#if .*} {
		    subst $line
		    set name [lindex $line 1];
		    set value [lindex $line 2];
		    set stack [list $iftrue $stack]
		    if {$iftrue && [info exists env($name)] && "$env($name)" == "$value"} {
			set iftrue 1;
		    } else {
			set iftrue 0;
		    }
		    #puts stderr "$line => $iftrue"
		}
		{^\#else.*} {
		    if {[lindex $stack 0]} {
			if {$iftrue} {
			    set iftrue 0;
			} else {
			    set iftrue 1;
			}
		    }
		}
		{^\#endif.*} {
		    set iftrue [lindex $stack 0];
		    set stack [lindex $stack 1];
		}
		{^.*=.*$} {
		    if {$iftrue} {
			if {[regexp {^[	]*(.*)[		]*=[	]*(.*)[		]*$} $line all name value]} {
			    du_options..option-value $name $value
			} else {
			    puts stderr "$file: $line"
			}
		    }
		}
	    }
	}
	close $o
    }
}

proc du_options..env {} {
    upvar dy_options dy_options
    global env
    foreach e [array name env DY_*] {
	du_options..option-value [string range $e 3 end] $env($e)
    }
}

proc du_options..args {argv} {
    upvar dy_options dy_options
    foreach {name value} $argv {
	if {[string match -glob -- -* $name]} {
	    du_options..option-value [string range $name 1 end] $value
	}
    }
}

#
# load the options database with the standard contents
# including the argv passed.
#
proc du_load_options {argv} {
    upvar \#0 du_options..database dy_options
    global env

    if { ! [info exists env(HOME)]} {
	set env(HOME) [glob ~]
    }

    if { ! [info exists env(DY_ROOT)]} {
	set env(DY_ROOT) /usr/local/daylight
    }
    
    if { ! [info exists env(DY_OPERATINGSYSTEM)]} {
	set env(DY_OPERATINGSYSTEM) [exec uname -s]
    }

    if { ! [info exists env(DY_HOSTNAME)]} {
	set env(DY_HOSTNAME) [exec uname -n]
    }

    if { ! [info exists env(DY_SYSPROFILE)]} {
	set env(DY_SYSPROFILE) $env(DY_ROOT)/etc/unix/dy_sysprofile.opt
    }
     
    if { ! [info exists env(DY_PROFILE)]} {
	set env(DY_PROFILE) $env(HOME)/dy_profile.opt
    }
     
    catch {unset dy_options}
    du_options..dot-dat $env(DY_ROOT)/etc/unix/dy_options.dat
    du_options..dot-opt $env(DY_SYSPROFILE)
    du_options..dot-opt $env(DY_PROFILE)
    du_options..env
    du_options..args $argv
}

#
# look up values for a list of options in the options database
# return a list of option value pairs suitable for storing into a tcl
# array with array set.
#
proc du_option_value_pairs {args} {
    upvar \#0 du_options..database dy_options
    if { ! [info exists dy_options]} {
	du_load_options {}
    }
    set options {}
    foreach arg $args {
	if {[info exists dy_options($arg)]} {
	    lappend options $arg $dy_options($arg)
	}
    }
    return $options;
}

#
# return the list of option names which match the given pattern
#
proc du_option_names {pattern} {
    upvar \#0 du_options..database dy_options
    if { ! [info exists dy_options]} {
	du_load_options {}
    }
    set names {}
    foreach name [array names dy_options $pattern] {
	if { ! [string match *:* $name]} {
	    lappend names $name;
	}
    }
    return $names
}

#
# return the value of a single option
#
proc du_option_value {option} {
    foreach {name value} [du_option_value_pairs $option] { return $value; }
    error "du_option_value: option $opt does not exist"
}

