package require Dayswig_tcl
package provide libdaytcl 1.0

#
#  du_print_pdb() -- write conformation to fp in PDB format, return success
#
#  This returns FALSE iff confs is null or empty.
#  H-coords for explicit H's are written to output.
#


proc du_print_pdb {fp confs pcn dohy src} {

    # Count sequence, fetch molecule and SMILES once.

   dt_reset $confs;
   set ntot [dt_count $confs [TYP_CONFORMATION]];
   if {0 == $ntot} {
       return 0;
   }

   # Loop over all conformations.

   set pos 0;
   foreach conf [du_stream_to_list $confs 1] {
       incr pos;

       # Get molecule from conformation.

       set mol [dt_base $conf];

       # Write remarks: SMILES name source runid rem

       set smi [dt_cansmiles $mol 0];
       puts $fp "REMARK SMILES $smi\n";

       if ("[NULL_OB] != pcn) fprintf(fp, "REMARK NAME   %s\n", pcn);

      if (NULL != src) fprintf(fp, "REMARK SOURCE %s\n", src);

      fprintf(fp, "REMARK RUNID  %d/%d\n", pos + 1, ntot);

      rem = dt_stringvalue(&lens, dt_adjunct(conf));
      if (NULL != rem) fprintf(fp, "REMARK FIT    %.*s\n", lens, rem);

      /*** Initialize per-element counts and atom index array. ***/

      memset(counts, '\0', 110);

      size  = dt_uidrange(mol, TYP_ATOM) * sizeof(int);
      iatom = (int *) malloc(size);
      memset((char *) iatom, '\0', size);
      atoms = dt_stream(mol, TYP_ATOM);
      for (i = 1; NULL_OB != (atom = dt_next(atoms)); i++)
	 iatom[dt_uid(atom)] = i;

      /*** Write out atom records, doing H's as needed (H+?). ***/

      dt_reset(atoms);
      for (i = 1; NULL_OB != (atom = dt_next(atoms)); i++) {
	 if (dohy || 1 != dt_number(atom) || 0 != dt_weight(atom)) {

	    fprintf(fp, "ATOM %6d ", i);
	    sy = dt_symbol(&lensy, atom);

	    if (2 == lensy) fprintf(fp, "%c%c", *sy, *(sy + 1) + 'A' - 'a');
	    else            fprintf(fp, " %c",  *sy);

	    if (99 > counts[dt_number(atom)])
	       fprintf(fp, "%-2d", ++counts[dt_number(atom)]);
	    else
	       fprintf(fp, "**");

	    dt_getcoord(conf, atom, &fx, &fy, &fz);
            fprintf(fp, " RES     1    %8.3f%8.3f%8.3f\n", fx, fy, fz);
         }
      }

      /*** Write out bond records, doing H's as needed. ***/

      fprintf(fp, "TER  %6d\n", dt_count(mol, TYP_BOND));

      dt_reset(atoms);
      for (i = 1; NULL_OB != (atom = dt_next(atoms)); i++) {
	 fprintf(fp, "CONECT%5d", iatom[dt_uid(atom)]);
	 bonds = dt_stream(atom, TYP_BOND);
	 while (NULL_OB != (bond = dt_next(bonds))) {
	    xatom = dt_xatom(atom, bond);
	    if (dohy || 1 != dt_number(xatom) || 0 != dt_weight(xatom)) {
	       ix = iatom[dt_uid(xatom)];
	       bo = dt_bondorder(bond);
	       while (bo--)
	          fprintf(fp, "%5d", ix);
	    }
	 }
	 dt_dealloc(bonds);
	 fprintf(fp, "\n");
      }

      /*** That's all for this one, folks! ***/

      fprintf(fp, "END\n");

      dt_dealloc(atoms);
      if (NULL != iatom) free(iatom);
   }

   /*** That's all, folks! ***/

   return TRUE;
}
