package require Dayswig_tcl
package provide libdaytcl 1.0

#
#  du_smilin_seq -- interpret SMILES in string into a sequence of molecules
#
#  This takes a NULL-terminated string and writes errors to stderr.
#  This treats the input string as a '.'-delimited list, which is
#  wrong since '.' can appear in a well formed smile without delimiting
#  anything.
#  


proc du_smilin_seq {smi} {

    # Interpret molecules, write messages, add to sequence.
    global NULL_OB
    set seq [dt_alloc_seq];
    foreach part [split $smi .] {
	if {[catch {dt_smilin $part} mol]} {
	    puts stderr $mol;
	    set mol $NULL_OB;
	}

	# If any part not interpreted, reject whole thing.

	if {"$NULL_OB" == "$mol"} {
	    dt_reset $seq;
	    foreach mol [du_stream_to_list $seq] {
		dt_dealloc $mol;
	    }
	    dt_dealloc $seq;
	    return $NULL_OB;
	}

	# Else, add molecule to sequence.

	dt_seqappend $seq $mol;
    }

    return $seq;
}
