
%title "Daylight Toolkit Bindings"
%if defined(SWIGTCL)
%module dayswig_tcl
%elif defined(SWIGPERL)
%module dayswig_perl
%elif defined(SWIGPYTHON)
%module dayswig_python
%elif defined(SWIGGUILE)
%module dayswig_guile
%endif

%include typemaps.i

%{
/*
** SWIG module for daylight toolkits.
*/

#include <dt_mdep.h>
#include <dt_datatype.h>
#include <dt_smiles.h>
#include <dt_monomer.h>
#include <dt_smarts.h>
#include <dt_finger.h>
#include <dt_progob.h>
#include <dt_thor.h>
#include <dt_merlin.h>
%}
%if defined(SWIGPYTHON)
%{
#include <dt_depict.h>
#include <dl_ga.h>
%}
%endif
%{

/* Convert daylight's nonterminated counted strings into nul terminated strings.
** Of course, some of these are binary and there's no warning which they are.
*/
static int swigSaveString_len;
static char *swigSaveString_str;
%}
%init %{
	swigSaveString_len = 128;
	swigSaveString_str = malloc(128);
#if defined(SWIGTCL)
	Tcl_PkgProvide(interp, "Dayswig_tcl", "0.3");
#endif

#if defined(SWIGPYTHON)
	/* Add the two daydepict functions to the module */
	/* Assumes that the SWIG implementation makes the local variable `d` */
        /*  available as the module dictionary! */
	{
	  PyMethodDef *ml;
	  PyObject *v;
          static PyMethodDef daydepict_methods[] = {

  {"depict", pydepict, METH_VARARGS,
    "depiction, callback object, color list -> non-zero on error\n\n"
    "Call the Daylight depiction, forwarding draw requests to methods of\n"
    "the callback object.  Colors are taken from the color list.\n"
  },
  {"getcoord", getcoord, METH_VARARGS, 
    "depiction, atom -> x, y, z tuple of the object's position in the depiction"
  },
    NULL,
          };

          for (ml = daydepict_methods; ml->ml_name != NULL; ml++) {
	    v = PyCFunction_New(ml, NULL);
	    if (v == NULL) {
	      continue;  /* even with failure, try the next one */
	    }
	    if (PyDict_SetItemString(d, ml->ml_name, v) != 0) {
	      continue;
	    }
	    Py_DECREF(v);
	  }
	}
#endif

%}
%{
static char *swigSaveString(int *lenp, char *str) {
	int len = *lenp;
	if (len < 0 || str == NULL) {
		len = 0;
		str = "";
		/* SWIG now allows return NULL, which gets translated into */
		/* whatever is appropriate for the language (eg, None for */
		/* Python, undef for Perl, etc.) */
		return NULL; 
	}
	if (len+1 > swigSaveString_len) {
		swigSaveString_str = realloc(swigSaveString_str, swigSaveString_len = len+1);
	}
	strncpy(swigSaveString_str, str, len);
	swigSaveString_str[len] = 0;
	return swigSaveString_str;
}
#if defined(SWIGPYTHON)
PyObject *pydepict(PyObject *self, PyObject *args);
PyObject *getcoord(PyObject *self, PyObject *args);

#endif

%}
%apply int*OUTPUT{dt_Integer*pstatus};
%apply int*OUTPUT{dt_Integer*ret_status};
%apply int*OUTPUT{dt_Integer*pret_status};
%apply int*OUTPUT{dt_Integer*return_status};
%apply int*OUTPUT{dt_Integer*isnew};
%apply int*OUTPUT{dt_Boolean*isnew};
%apply int*OUTPUT{dt_Integer*iserror};
%apply int*OUTPUT{dt_Integer*errcode};
%apply int*OUTPUT{dt_Integer*pr2};
%apply int*OUTPUT{dt_Integer*soffset};
%apply  unsigned int    *OUTPUT{dt_Handle*pm2};


%section "dt_mdep.h"
typedef int		dt_Boolean;
typedef int		dt_Integer;
typedef float		dt_Real;
typedef char *		dt_String;
typedef unsigned int    dt_Handle;
#define NULL_OB 0
	/* no description */
#define DM_MAX_USERID 100
	/*  max length of userid string		 */
#define DM_MAX_PASSWORD 100
	/*  max length of password string	 */
#define DM_MAX_PATHLEN 400
	/*  max length of a file's path		 */
#define DM_MAX_HOSTNAME 400
	/*  max length of host + domain address	 */
#define DM_MAX_SERVICE 100
	/*  max length of IPC service name	 */
#define DM_MAX_TAG 40
	/*  max length of THOR datatype tag	 */
#define DX_TOOLKIT_LICENSE 1
	/* no description */
#define DX_PROGRAM_LICENSE 2
	/* no description */
#define DX_SERVER_LICENSE 3
	/* no description */
#define DX_DATABASE_LICENSE 4
	/* no description */
%section "dt_datatype.h"
#define DT_DATATYPE_INCLUDED 1
	/* no description */
#define DX_THOR_USMILES 0x0001
	/*  unique SMILES                      */
#define DX_THOR_ASMILES 0x0002
	/*  absolute SMILES                    */
#define DX_THOR_GRAPH 0x0004
	/*  convert SMILES to GRAPH            */
#define DX_THOR_MAKEGRAPH 0x0008
	/*  produce a GRAPH subtree            */
#define DX_THOR_WHITE0 0x0010
	/*  zap spaces                         */
#define DX_THOR_WHITE1 0x0020
	/*  zap 2 or more spaces               */
#define DX_THOR_WHITE2 0x0040
	/*  zap 3 or more spaces               */
#define DX_THOR_UPCASE 0x0080
	/*  convert to upcase                  */
#define DX_THOR_DOWNCASE 0x0100
	/*  convert to downcase                */
#define DX_THOR_NOPUNCT 0x0200
	/*  zap punctuation                    */
#define DX_THOR_SOMEPUNCT 0x0400
	/*  zap some punctuation               */
#define DX_THOR_CASNUM 0x0800
	/*  insert hyphens and checksum        */
#define DX_THOR_D3D 0x1000
	/*  compute 3D hash               (WO) */
#define DX_THOR_REGEXP 0x2000
	/*  must match regexp             (WO) */
#define DX_THOR_SMILES_NTUPLE 0x4000
	/*  SMILES-order n-tuple data     (WO) */
#define DX_THOR_BINARY 0x08000
	/*  binary data                        */
#define DX_THOR_READONLY 0x10000
	/*  field can't be set by user    (WO) */
#define DX_THOR_NUMERIC 0x20000
	/*  field is numeric                   */
#define DX_THOR_INDIRECT 0x40000
	/*  indirect data field                */
#define DX_THOR_USMILESANY 0x80000
	/*  unique SMILES, no match to root    */
#define DX_THOR_ASMILESANY 0x100000
	/*  abs. SMILES, no match to root      */
#define DX_THOR_AUTOGEN 0x200000
	/*  automatically generate dataitem    */
#define DX_THOR_CHUCKLES 0x400000
	/*  unique CHUCKLES                    */
#define DX_THOR_CHORTLES 0x800000
	/*  unique CHORTLES                    */
#define DX_THOR_NCHUCKLES 0x1000000
	/*  non-unique CHUCKLES                */
#define DX_THOR_NCHORTLES 0x2000000
	/*  non-unique CHORTLES                */
#define DX_THOR_PART_NTUPLE 0x4000000
	/*  SMILES-order part n-tuple data(WO) */
#define DX_THOR_MAKERXNMOL 0x8000000
	/*  generate reaction molecules        */
#define DX_THOR_UNUSED 0x10000000
	/*  remember: 32 bits total            */
#define DX_THOR_WO_NORMS (DX_THOR_D3D | DX_THOR_REGEXP | DX_THOR_SMILES_NTUPLE | DX_THOR_PART_NTUPLE)
	/* no description */
#define DX_THOR_LOOKUP_NORMS (DX_THOR_USMILES     | DX_THOR_ASMILES     | DX_THOR_GRAPH      |  DX_THOR_USMILESANY  | DX_THOR_ASMILESANY  |                       DX_THOR_WHITE0      | DX_THOR_WHITE1      | DX_THOR_WHITE2     |  DX_THOR_UPCASE      | DX_THOR_DOWNCASE    | DX_THOR_NOPUNCT    |  DX_THOR_SOMEPUNCT   | DX_THOR_CASNUM      |                       DX_THOR_CHUCKLES    | DX_THOR_CHORTLES    |                       DX_THOR_NCHUCKLES   | DX_THOR_NCHORTLES   )
	/* no description */
#define DX_THOR_ANYSMILES (  DX_THOR_USMILES  | DX_THOR_ASMILES  | DX_THOR_USMILESANY  | DX_THOR_ASMILESANY)
	/* no description */
%inline %{
#undef dt_comments	/* S IpH */
static dt_String dt_comments(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_comments(&i,h)); }
%}
/* retrieve the datatype comments of a datatype object */
%inline %{
#undef dt_membership	/* S IpH */
static dt_String dt_membership(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_membership(&i,h)); }
%}
/* retrieve the membership of a datatype */
%inline %{
#undef dt_owner	/* S IpH */
static dt_String dt_owner(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_owner(&i,h)); }
%}
/* return the owner attribute of a datatype */
%section "dt_smiles.h"
#define DT_SMILES_INCLUDED 1
	/* no description */
dt_Boolean dt_abort(dt_Handle ob);
/* abort a server background task */
dt_Handle dt_add(dt_Handle ob, dt_Handle elt);
/* add an object to a set object */
dt_Handle dt_addatom(dt_Handle ob, dt_Integer atno, dt_Integer hct);
/* add an atom to a molecule */
dt_Handle dt_addbond(dt_Handle a0, dt_Handle a1, dt_Integer btyp);
/* add a bond between two atoms to a molecule */
dt_Handle dt_addcomponent(dt_Handle rxn, dt_Handle mol,dt_Integer role);
/* add a component object to a reaction object */
dt_Handle dt_adjunct(dt_Handle ob);
/* retrieve the adjunct object of an object */
dt_Handle dt_alloc_integer(void);
/* allocate a new integer object */
dt_Handle dt_alloc_mol(void);
/* allocate a new molecule object */
dt_Handle dt_alloc_path(dt_Handle mh);
/* allocate a new path object */
dt_Handle dt_alloc_reaction(void);
/* allocate a new reaction object */
dt_Handle dt_alloc_real(void);
/* allocate a new real object */
dt_Handle dt_alloc_seq(void);
/* allocate a new sequence object */
%inline %{
#undef dt_alloc_string	/* H IS */
static dt_Handle dt_alloc_string(dt_String s) { return dt_e_alloc_string(strlen(s),s); }
%}
/* allocate a new string object */
dt_Handle dt_alloc_substruct(dt_Handle mh);
/* allocate a new substructure object */
dt_Handle dt_append(dt_Handle ob, dt_Handle elt);
/* append an object to the end of a compound object */
dt_Integer dt_arborder(dt_Handle ob);
/* retrieve the arbitrary order value for an atom */
%inline %{
#undef dt_arbsmiles	/* S IpHB */
static dt_String dt_arbsmiles(dt_Handle h,dt_Boolean b) { dt_Integer i; return swigSaveString(&i,dt_e_arbsmiles(&i,h,b)); }
%}
/* retrieve a SMILES string with arbitrarily ordered atoms */
dt_Handle dt_arbstream(dt_Handle mh, dt_Integer type,dt_Boolean iso, dt_Boolean addh);
/* retrieve a stream of objects in an arbitrary order */
dt_Boolean dt_aromatic(dt_Handle ob);
/* test whether an object is aromatic */
%inline %{
#undef dt_ascii2binary	/* H IS */
static dt_Handle dt_ascii2binary(dt_String s) { return dt_e_ascii2binary(strlen(s),s); }
%}
/* retrieve a binary string from its ascii representation */
dt_Boolean dt_atend(dt_Handle ob);
/* test if a compound object iteration is at its end */
dt_Boolean dt_atstart(dt_Handle ob);
/* test if a compound object iteration is at its start */
dt_Handle dt_base(dt_Handle ob);
/* retrieve the base object of an object */
%inline %{
#undef dt_binary2ascii	/* H IS */
static dt_Handle dt_binary2ascii(dt_String s) { return dt_e_binary2ascii(strlen(s),s); }
%}
/* retrieve an ascii representation of a binary string */
%inline %{
#undef dt_binary2asciilen	/* I IS */
static dt_Integer dt_binary2asciilen(dt_String s) { return dt_e_binary2asciilen(strlen(s),s); }
%}
/* retrieve the length of an ascii representation of a binary string */
dt_Handle dt_bond(dt_Handle a0, dt_Handle a1);
/* retrieve the bond connecting two atoms */
dt_Integer dt_bondorder(dt_Handle ob);
/* retrieve the bond order of a bond */
dt_Integer dt_bondtype(dt_Handle ob);
/* retrieve the type of a bond */
%inline %{
#undef dt_boolean	/* B HIS */
static dt_Boolean dt_boolean(dt_Handle h,dt_String s) { return dt_e_boolean(h,strlen(s),s); }
%}
/* retrieve the boolean value of a named property */
%inline %{
#undef dt_briefname	/* S IpH */
static dt_String dt_briefname(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_briefname(&i,h)); }
%}
/* retrieve the datatype's briefname */
dt_Handle dt_canstream(dt_Handle mh, dt_Integer type,dt_Boolean iso, dt_Boolean addh);
/* retrieve a stream of objects in canonical order */
%inline %{
#undef dt_cansmiles	/* S IpHB */
static dt_String dt_cansmiles(dt_Handle h,dt_Boolean b) { dt_Integer i; return swigSaveString(&i,dt_e_cansmiles(&i,h,b)); }
%}
/* retrieve the canonical SMILES string of an object */
dt_Integer dt_charge(dt_Handle ob);
/* retrieve the formal charge of an atom */
%inline %{
#undef dt_check_license	/* I IIS */
static dt_Integer dt_check_license(dt_Integer i,dt_String s) { return dt_e_check_license(i,strlen(s),s); }
%}
/* test whether a Daylight product is licensed */
dt_Integer dt_chiclass(dt_Integer chival);
/* retrieve the chiral class */
dt_Integer dt_chiorder(dt_Integer chival);
/* retrieve the chiral order  */
dt_Handle dt_chiperm(dt_Handle bseqh, dt_Handle bh, dt_Integer chival);
/* permute a bond to first in a sequence of bonds preserving chirality */
dt_Handle dt_chiseq(dt_Handle a, dt_Integer v);
/* retrieve a stream of bonds having specified chirality */
dt_Integer dt_chival(dt_Handle a, dt_Handle s);
/* compute the chiral value around an atom */
dt_Integer dt_continue(dt_Handle s, dt_Integer *return_status);
/* continue a task in progress */
dt_Handle dt_copy(dt_Handle ob);
/* make a copy of an object */
dt_Integer dt_count(dt_Handle ob, dt_Integer typ);
/* return the number of objects of a type in a compound object */
dt_Handle dt_database(dt_Handle ob);
/* find the database of an object */
dt_Handle dt_datatype(dt_Handle ob);
/* find the datatype of an object */
dt_Integer dt_dbo(dt_Handle ob, dt_Handle b0, dt_Handle b1);
/* dt_dbo */
%inline %{
#undef dt_define	/* B HISIS */
static dt_Boolean dt_define(dt_Handle h,dt_String s,dt_String s2) { return dt_e_define(h,strlen(s),s,strlen(s2),s2); }
%}
/* add a definition to a monomertable */
dt_Boolean dt_dealloc(dt_Handle ob);
/* remove an object from the system */
dt_Boolean dt_delete(dt_Handle ob);
/* delete an object from a compound object */
%inline %{
#undef dt_description	/* S IpH */
static dt_String dt_description(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_description(&i,h)); }
%}
/* retrieve the datatype description dataitem */
dt_Boolean dt_dfnorm(dt_Handle ob, dt_Integer norm);
/* tests if an object was normalized in a particular way */
%inline %{
#undef dt_dfnormdata	/* S IpHI */
static dt_String dt_dfnormdata(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_dfnormdata(&i,h,i2)); }
%}
/* retrieve extra data for a normalization */
dt_Integer dt_done_when(dt_Handle ob);
/* estimate completion time for a task */
void dt_errorclear(void);
/* discard pending error messages */
dt_Integer dt_errorworst(void);
/* retrieve the level of the worst error recorded */
dt_Handle dt_errors(dt_Integer lev);
/* retrieve errors of severity or greater */
dt_Boolean dt_errorsave(dt_String func, dt_Integer lev, dt_String msg);
/* store an error in the error queue */
%inline %{
#undef dt_evict	/* I HISISHB */
static dt_Integer dt_evict(dt_Handle h,dt_String s,dt_String s2,dt_Handle h2,dt_Boolean b) { return dt_e_evict(h,strlen(s),s,strlen(s2),s2,h2,b); }
%}
/* evict clients from a server */
%inline %{
#undef dt_exists	/* B HIS */
static dt_Boolean dt_exists(dt_Handle h,dt_String s) { return dt_e_exists(h,strlen(s),s); }
%}
/* test to see if a database exists */
dt_Handle dt_fieldtype(dt_Handle ob);
/* retrieve the fieldtype associated with an object */
dt_Handle dt_getdatabases(dt_Handle server);
/* get the current list of databases in a server's search path */
%inline %{
#undef dt_getdatatype	/* H HIS */
static dt_Handle dt_getdatatype(dt_Handle h, dt_String s) { return dt_e_getdatatype(h,strlen(s),s); }
%}
/* get a datatype definition associated with a tag */
dt_Handle dt_getmap(dt_Handle atom);
/* find all the atoms in a map class */
dt_Handle dt_getpasswords(dt_Handle server);
/* get the passwords for a server */
dt_Integer dt_getrole(dt_Handle ob1, dt_Handle ob2);
/* get the role an object plays in a reaction */
dt_Handle dt_getsearchpath(dt_Handle server);
/* get the current database search path */
dt_Handle dt_getusers(dt_Handle server);
/* get the current list of users of an object */
%inline %{
#undef dt_handle	/* H HIS */
static dt_Handle dt_handle(dt_Handle h, dt_String s) { return dt_e_handle(h,strlen(s),s); }
%}
/* retrieve the handle value of a named property */
dt_Integer dt_hcount(dt_Handle ob);
/* retrieve the hydrogen count for an atom */
%inline %{
#undef dt_hold	/* B HIS */
static dt_Boolean dt_hold(dt_Handle h,dt_String s) { return dt_e_hold(h,strlen(s),s); }
%}
/* mark an object as held */
dt_Integer dt_imp_hcount(dt_Handle ob);
/* retrieve the implicit hydrogen count of an atom */
%inline %{
#undef dt_info	/* S IpHS */
static dt_String dt_info(dt_Handle h,dt_String s2) { dt_Integer i; return swigSaveString(&i,dt_e_info(&i,h,s2)); }
%}
/* retrieve information on an object */
dt_Handle dt_insert(dt_Handle ob, dt_Handle elt);
/* insert an object into a sequence */
%inline %{
#undef dt_integer	/* I HIS */
static dt_Integer dt_integer(dt_Handle h,dt_String s) { return dt_e_integer(h,strlen(s),s); }
%}
/* retrieve the integer value of a named property */
dt_Integer dt_integervalue(dt_Handle ob);
/* retrieve the integer value of an object */
dt_Boolean dt_invalid(dt_Handle ob);
/* test if an object handle is invalid */
dt_Boolean dt_isheld(dt_Handle ob);
/* test if an object is marked as held */
%inline %{
#undef dt_isopen	/* B HIS */
static dt_Boolean dt_isopen(dt_Handle h,dt_String s) { return dt_e_isopen(h,strlen(s),s); }
%}
/* test if a database is open */
%inline %{
#undef dt_ispublic	/* B HIS */
static dt_Boolean dt_ispublic(dt_Handle h,dt_String s) { return dt_e_ispublic(h,strlen(s),s); }
%}
/* test if a database is public */
dt_Handle dt_isohydro(void);
/* retrieve the isomeric hydrogen atom */
dt_Boolean dt_mapped(dt_Handle a1, dt_Handle a2);
/* test if two atoms are in the same map class */
dt_Handle dt_match(dt_Handle ob, dt_Handle mol, dt_Integer exists);
/* match a pattern against a target */
dt_Boolean dt_member(dt_Handle ob, dt_Handle elt);
/* test if an object is a member of a compound object */
dt_Boolean dt_mod_is_on(dt_Handle ob);
/* determine whether an object may be modified */
dt_Boolean dt_mod_off(dt_Handle ob);
/* specify that an object may not be modified */
dt_Boolean dt_mod_on(dt_Handle ob);
/* specify than an object may be modified */
dt_Handle dt_molecule(dt_Handle ob);
/* return the molecule of an object */
dt_Handle dt_monomertable(dt_Handle ob);
/* retrieve the monomertable of an object */
%inline %{
#undef dt_name	/* S IpH */
static dt_String dt_name(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_name(&i,h)); }
%}
/* return the name of an object */
dt_Handle dt_next(dt_Handle ob);
/* retrieve the next object in a compound object */
dt_Integer dt_number(dt_Handle ob);
/* retrieve the atomic number of an atom object */
%inline %{
#undef dt_open	/* H HISISISIp */
static dt_Handle dt_open(dt_Handle h,dt_String s,dt_String s2,dt_String s3,dt_Integer *isnew) { return dt_e_open(h,strlen(s),s,strlen(s2),s2,strlen(s3),s3,isnew); }
%}
/* open a database */
dt_Handle dt_origstream(dt_Handle mh, dt_Integer type);
/* retrieve a stream of objects ordered as they were created */
dt_Handle dt_parent(dt_Handle ob);
/* retrieve the parent object of an object */
%inline %{
#undef dt_ping	/* I HIS */
static dt_Integer dt_ping(dt_Handle h,dt_String s) { return dt_e_ping(h,strlen(s),s); }
%}
/* test a server's ability to respond */
dt_Handle dt_propnames(dt_Handle ob);
/* retrieve the names of an object's properties */
%inline %{
#undef dt_proptype	/* I HIS */
static dt_Integer dt_proptype(dt_Handle h,dt_String s) { return dt_e_proptype(h,strlen(s),s); }
%}
/* retrieve the type of a named property */
%inline %{
#undef dt_real	/* R HIS */
static dt_Real dt_real(dt_Handle h,dt_String s) { return dt_e_real(h,strlen(s),s); }
%}
/* retrieve the real value of a named property */
dt_Real dt_realvalue(dt_Handle ob);
/* retrieve the real value of an object */
%inline %{
#undef dt_release	/* B HIS */
static dt_Boolean dt_release(dt_Handle h,dt_String s) { return dt_e_release(h,strlen(s),s); }
%}
/* release an object from a server's retained list */
dt_Boolean dt_remove(dt_Handle ob, dt_Handle elt);
/* remove an object from a compound object */
dt_Boolean dt_reset(dt_Handle ob);
/* reset the iteration state of a compound object */
dt_Boolean dt_seqsort(dt_Handle ob);
/* sort objects in a sequence by string values */
dt_Handle dt_server(dt_Handle ob);
/* find the server which owns an object */
dt_Integer dt_set_server_timeout(dt_Integer new_time);
/* specify the connection time out */
dt_Handle dt_setadjunct(dt_Handle ob, dt_Handle adj);
/* specify the adjunct value of an object */
dt_Boolean dt_setarborder(dt_Handle ob, dt_Integer val);
/* specify the arbitrary order of an atom in an object */
dt_Boolean dt_setaromatic(dt_Handle ob, dt_Boolean val);
/* specify the aromaticity of an atom object */
%inline %{
#undef dt_setboolean	/* B HISB */
static dt_Boolean dt_setboolean(dt_Handle h,dt_String s,dt_Boolean b) { return dt_e_setboolean(h,strlen(s),s,b); }
%}
/* specify the boolean value of a named property */
dt_Boolean dt_setbondorder(dt_Handle ob, dt_Integer val);
/* specify the bond order of a bond object */
dt_Boolean dt_setbondtype(dt_Handle ob, dt_Integer val);
/* specify the type of a bond object */
dt_Boolean dt_setcharge(dt_Handle ob, dt_Integer val);
/* specify the charge of an atom object */
dt_Boolean dt_setchival(dt_Handle a, dt_Handle s, dt_Integer v);
/* specify the chiral value of an atom object */
dt_Boolean dt_setdbo(dt_Handle ob, dt_Handle b0, dt_Handle b1,dt_Integer v);
/* specify the double bond orientation for three bonds */
%inline %{
#undef dt_sethandle	/* B HISH */
static dt_Boolean dt_sethandle(dt_Handle h,dt_String s,dt_Handle h2) { return dt_e_sethandle(h,strlen(s),s,h2); }
%}
/* specify the handle value for a named property */
dt_Boolean dt_setimp_hcount(dt_Handle ob, dt_Integer val);
/* specify the implicit hydrogen count for an atom object */
%inline %{
#undef dt_setinteger	/* B HISI */
static dt_Boolean dt_setinteger(dt_Handle h,dt_String s,dt_Integer i) { return dt_e_setinteger(h,strlen(s),s,i); }
%}
/* specify the integer value of a named property */
dt_Boolean dt_setintegervalue(dt_Handle ob, dt_Integer value);
/* specify the integer value for an object */
dt_Boolean dt_setmap(dt_Handle a1, dt_Handle a2);
/* merge the reaction map classes of two atoms  */
%inline %{
#undef dt_setmessage	/* B HISIH */
static dt_Boolean dt_setmessage(dt_Handle h,dt_String s,dt_Integer i,dt_Handle h2) { return dt_e_setmessage(h,strlen(s),s,i,h2); }
%}
/* notify users of a Thor or Merlin database */
dt_Boolean dt_setnumber(dt_Handle ob, dt_Integer val);
/* specify the atomic number of an atom object */
dt_Boolean dt_setpassword(dt_Handle ob, dt_String what,dt_String oldpw, dt_String newpw);
/* specify entries in a password file */
%inline %{
#undef dt_setreal	/* B HISR */
static dt_Boolean dt_setreal(dt_Handle h,dt_String s,dt_Real r) { return dt_e_setreal(h,strlen(s),s,r); }
%}
/* specify the real value of a named property */
dt_Boolean dt_setrealvalue(dt_Handle ob, dt_Real value);
/* specify the real value of an object */
%inline %{
#undef dt_setsearchpath	/* B HISISI */
static dt_Boolean dt_setsearchpath(dt_Handle h,dt_String s,dt_String s2,dt_Integer i) { return dt_e_setsearchpath(h,strlen(s),s,strlen(s2),s2,i); }
%}
/* specify the search path used for database lookup */
%inline %{
#undef dt_setstring_invalid	/* B HISIS */
static dt_Boolean dt_setstring_invalid(dt_Handle h, dt_String s) { return dt_e_setstring(h,strlen(s),s,-1,NULL); }
%}
/* entry to dt_setstring() that requires no invalid string */
%inline %{
#undef dt_setstring	/* B HISIS */
static dt_Boolean dt_setstring(dt_Handle h,dt_String s,dt_String s2) { return dt_e_setstring(h,strlen(s),s,strlen(s2),s2); }
%}
/* set the string value of a named property */
%inline %{
#undef dt_setstringvalue	/* B HIS */
static dt_Boolean dt_setstringvalue(dt_Handle h,dt_String s) { return dt_e_setstringvalue(h,strlen(s),s); }
%}
/* specify the string value of an object */
dt_Boolean dt_setweight(dt_Handle ob, dt_Integer val);
/* specify the atomic weight of an atom */
%inline %{
#undef dt_smiles	/* S IpH */
static dt_String dt_smiles(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_smiles(&i,h)); }
%}
/* convert an object to a SMILES string */
%inline %{
#undef dt_smilin	/* H IS */
static dt_Handle dt_smilin(dt_String s) { return dt_e_smilin(strlen(s),s); }
%}
/* interpret a SMILES string */
dt_Handle dt_smilinerrors(void);
/* return all errors related to smiles parsing */
dt_Handle dt_stream(dt_Handle ob, dt_Integer typ);
/* allocate a stream object */
%inline %{
#undef dt_string	/* S IpHIS */
static dt_String dt_string(dt_Handle h,dt_String s2) { dt_Integer i; return swigSaveString(&i,dt_e_string(&i,h,strlen(s2),s2)); }
%}
/* return the string value of a named property of an object */
%inline %{
#undef dt_stringvalue	/* S IpH */
static dt_String dt_stringvalue(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_stringvalue(&i,h)); }
%}
/* return the string value of an object */
%inline %{
#undef dt_summary	/* S IpH */
static dt_String dt_summary(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_summary(&i,h)); }
%}
/* find the datatype summary of an object */
%inline %{
#undef dt_symbol	/* S IpH */
static dt_String dt_symbol(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_symbol(&i,h)); }
%}
/* find the symbolic name for an object */
dt_Integer dt_symclass(dt_Handle ob, dt_Boolean i);
/* find the symmetry class of an atom */
dt_Integer dt_symorder(dt_Handle ob, dt_Boolean i);
/* find the symmetry order for an atom */
%inline %{
#undef dt_tag	/* S IpH */
static dt_String dt_tag(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_tag(&i,h)); }
%}
/* return the datatype tag of an object */
dt_Boolean dt_toend(dt_Handle ob);
/* advance to the end of an object */
dt_Integer dt_type(dt_Handle ob);
/* return the type of an object */
%inline %{
#undef dt_typename	/* S IpH */
static dt_String dt_typename(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_typename(&i,h)); }
%}
/* return the type name of an object */
dt_Integer dt_uid(dt_Handle ob);
/* find the 'unique ID' of an object */
dt_Integer dt_uidrange(dt_Handle ob, dt_Integer typ);
/* find the maximum 'unique ID' in an object */
dt_Integer dt_weight(dt_Handle ob);
/* return the atomic weight of an atom */
dt_Handle dt_xatom(dt_Handle a, dt_Handle b);
/* find the atom across a bond from an atom */
#define DX_ERR_NONE 0
	/*  No error.  */
#define DX_ERR_NOTE 1
	/*  Note.  */
#define DX_ERR_WARN 2
	/*  Warning.  */
#define DX_ERR_ERROR 3
	/*  Real error.  */
#define DX_ERR_FATAL 4
	/*  Toolkit probably can't continue.  */
#define DX_BTY_UNKNOWN 0
	/* no description */
#define DX_BTY_SINGLE 1
	/* no description */
#define DX_BTY_DOUBLE 2
	/* no description */
#define DX_BTY_TRIPLE 3
	/* no description */
#define DX_BTY_AROMAT 4
	/* no description */
#define DX_BTY_WILD 5
	/* no description */
#define DX_BTY_NONE 6
	/* no description */
#define DX_BTY_COUNT (DX_BTY_NONE+1)
	/* no description */
#define DX_CHI_NONE 0
	/*  No chirality  */
#define DX_CHI_TH 3
	/*  Tetrahedral  */
#define DX_CHI_AL 4
	/*  Tetrahedral  */
#define DX_CHI_SP 16
	/*  Square Planar  */
#define DX_CHI_TB 17
	/*  Trigonal Bipyramidal  */
#define DX_CHI_OH 18
	/*  Octahedral  */
#define DX_CHI_THCCW 196609
	/* no description */
#define DX_CHI_THCW 196610
	/* no description */
#define DX_CHI_NO_DBO 0
	/*  No orientation  */
#define DX_CHI_CIS 1
	/*  Cis (same-side) orientation  */
#define DX_CHI_TRANS 2
	/*  Trans (opposite-side) orientation  */
#define DX_ROLE_REACTANT 1
	/* no description */
#define DX_ROLE_AGENT 2
	/* no description */
#define DX_ROLE_PRODUCT 3
	/* no description */
#define DX_ROLE_ANY 4
	/* no description */
#define DX_FORWARD 0
	/* no description */
#define DX_REVERSE 1
	/* no description */
#define DX_PROP_STRING 1
	/* no description */
#define DX_PROP_INTEGER 2
	/* no description */
#define DX_PROP_BOOLEAN 3
	/* no description */
#define DX_PROP_REAL 4
	/* no description */
#define DX_PROP_HANDLE 5
	/* no description */
#define DX_PROP_NOPROP 0
	/* no description */
#define TYP_ANY 1
	/* no description */
#define TYP_INTEGER 13
	/* no description */
#define TYP_REAL 14
	/* no description */
#define TYP_STRING 15
	/* no description */
#define TYP_MOLECULE 16
	/* no description */
#define TYP_CONFORMATION 17
	/* no description */
#define TYP_DEPICTION 18
	/* no description */
#define TYP_ATOM 19
	/* no description */
#define TYP_BOND 20
	/* no description */
#define TYP_CYCLE 21
	/* no description */
#define TYP_STREAM 22
	/* no description */
#define TYP_SEQUENCE 23
	/* no description */
#define TYP_SUBSTRUCT 24
	/* no description */
#define TYP_PATH 25
	/* no description */
#define TYP_PATTERN 26
	/* no description */
#define TYP_VBIND 27
	/* no description */
#define TYP_PATHSET 28
	/* no description */
#define TYP_SERVER 30
	/* no description */
#define TYP_DATABASE 31
	/* no description */
#define TYP_DATATREE 32
	/* no description */
#define TYP_DATAITEM 33
	/* no description */
#define TYP_DATAFIELD 34
	/* no description */
#define TYP_DATATYPE 35
	/* no description */
#define TYP_FIELDTYPE 36
	/* no description */
#define TYP_FINGERPRINT 40
	/* no description */
#define TYP_MERSERVER 50
	/* no description */
#define TYP_POOL 51
	/* no description */
#define TYP_HITLIST 52
	/* no description */
#define TYP_COLUMN 53
	/* no description */
#define TYP_MONOMERTABLE 60
	/* no description */
#define TYP_MONOMER 61
	/* no description */
#define TYP_MONOMERSET 62
	/* no description */
#define TYP_MULTIMER 63
	/* no description */
#define TYP_VARIMER 64
	/* no description */
#define TYP_MONOPATTERN 65
	/* no description */
#define TYP_VARIPATTERN 66
	/* no description */
#define TYP_PROGRAM 70
	/* no description */
#define TYP_REACTION 80
	/* no description */
#define TYP_TRANSFORM 81
	/* no description */
#define DX_ATN_H 1
	/*  Hydrogen  */
#define DX_ATN_He 2
	/*  Helium  */
#define DX_ATN_Li 3
	/*  Lithium  */
#define DX_ATN_Be 4
	/*  Beryllium  */
#define DX_ATN_B 5
	/*  Boron  */
#define DX_ATN_C 6
	/*  Carbon  */
#define DX_ATN_N 7
	/*  Nitrogen  */
#define DX_ATN_O 8
	/*  Oxygen  */
#define DX_ATN_F 9
	/*  Fluorine  */
#define DX_ATN_Ne 10
	/*  Neon  */
#define DX_ATN_Na 11
	/*  Sodium  */
#define DX_ATN_Mg 12
	/*  Magnesium  */
#define DX_ATN_Al 13
	/*  Aluminum  */
#define DX_ATN_Si 14
	/*  Silicon  */
#define DX_ATN_P 15
	/*  Phosphorus  */
#define DX_ATN_S 16
	/*  Sulfur  */
#define DX_ATN_Cl 17
	/*  Chlorine  */
#define DX_ATN_Ar 18
	/*  Argon  */
#define DX_ATN_K 19
	/*  Potassium  */
#define DX_ATN_Ca 20
	/*  Calcium  */
#define DX_ATN_Sc 21
	/*  Scandium  */
#define DX_ATN_Ti 22
	/*  Titanium  */
#define DX_ATN_V 23
	/*  Vanadium  */
#define DX_ATN_Cr 24
	/*  Chromium  */
#define DX_ATN_Mn 25
	/*  Manganese  */
#define DX_ATN_Fe 26
	/*  Iron  */
#define DX_ATN_Co 27
	/*  Cobalt  */
#define DX_ATN_Ni 28
	/*  Nickel  */
#define DX_ATN_Cu 29
	/*  Copper  */
#define DX_ATN_Zn 30
	/*  Zinc  */
#define DX_ATN_Ga 31
	/*  Gallium  */
#define DX_ATN_Ge 32
	/*  Germanium  */
#define DX_ATN_As 33
	/*  Arsenic  */
#define DX_ATN_Se 34
	/*  Selenium  */
#define DX_ATN_Br 35
	/*  Bromine  */
#define DX_ATN_Kr 36
	/*  Krypton  */
#define DX_ATN_Rb 37
	/*  Rubidium  */
#define DX_ATN_Sr 38
	/*  Strontium  */
#define DX_ATN_Y 39
	/*  Yttrium  */
#define DX_ATN_Zr 40
	/*  Zirconium  */
#define DX_ATN_Nb 41
	/*  Niobium  */
#define DX_ATN_Mo 42
	/*  Molybdenum  */
#define DX_ATN_Tc 43
	/*  Technetium  */
#define DX_ATN_Ru 44
	/*  Ruthenium  */
#define DX_ATN_Rh 45
	/*  Rhodium  */
#define DX_ATN_Pd 46
	/*  Palladium  */
#define DX_ATN_Ag 47
	/*  Silver  */
#define DX_ATN_Cd 48
	/*  Cadmium  */
#define DX_ATN_In 49
	/*  Indium  */
#define DX_ATN_Sn 50
	/*  Tin  */
#define DX_ATN_Sb 51
	/*  Antimony  */
#define DX_ATN_Te 52
	/*  Tellurium  */
#define DX_ATN_I 53
	/*  Iodine  */
#define DX_ATN_Xe 54
	/*  Xenon  */
#define DX_ATN_Cs 55
	/*  Cesium  */
#define DX_ATN_Ba 56
	/*  Barium  */
#define DX_ATN_La 57
	/*  Lanthanum  */
#define DX_ATN_Ce 58
	/*  Cerium  */
#define DX_ATN_Pr 59
	/*  Praseodymium  */
#define DX_ATN_Nd 60
	/*  Neodymium  */
#define DX_ATN_Pm 61
	/*  Promethium  */
#define DX_ATN_Sm 62
	/*  Samarium  */
#define DX_ATN_Eu 63
	/*  Europium  */
#define DX_ATN_Gd 64
	/*  Gadolinium  */
#define DX_ATN_Tb 65
	/*  Terbium  */
#define DX_ATN_Dy 66
	/*  Dysprosium  */
#define DX_ATN_Ho 67
	/*  Holmium  */
#define DX_ATN_Er 68
	/*  Erbium  */
#define DX_ATN_Tm 69
	/*  Thulium  */
#define DX_ATN_Yb 70
	/*  Ytterbium  */
#define DX_ATN_Lu 71
	/*  Lutetium  */
#define DX_ATN_Hf 72
	/*  Hafnium  */
#define DX_ATN_Ta 73
	/*  Tantalum  */
#define DX_ATN_W 74
	/*  Tungsten  */
#define DX_ATN_Re 75
	/*  Rhenium  */
#define DX_ATN_Os 76
	/*  Osmium  */
#define DX_ATN_Ir 77
	/*  Iridium  */
#define DX_ATN_Pt 78
	/*  Platinum  */
#define DX_ATN_Au 79
	/*  Gold  */
#define DX_ATN_Hg 80
	/*  Mercury  */
#define DX_ATN_Tl 81
	/*  Thallium  */
#define DX_ATN_Pb 82
	/*  Lead  */
#define DX_ATN_Bi 83
	/*  Bismuth  */
#define DX_ATN_Po 84
	/*  Polonium  */
#define DX_ATN_At 85
	/*  Astatine  */
#define DX_ATN_Rn 86
	/*  Radon  */
#define DX_ATN_Fr 87
	/*  Francium  */
#define DX_ATN_Ra 88
	/*  Radium  */
#define DX_ATN_Ac 89
	/*  Actinium  */
#define DX_ATN_Th 90
	/*  Thorium  */
#define DX_ATN_Pa 91
	/*  Protactinium  */
#define DX_ATN_U 92
	/*  Uranium  */
#define DX_ATN_Np 93
	/*  Neptunium  */
#define DX_ATN_Pu 94
	/*  Plutonium  */
#define DX_ATN_Am 95
	/*  Americium  */
#define DX_ATN_Cm 96
	/*  Curium  */
#define DX_ATN_Bk 97
	/*  Berkelium  */
#define DX_ATN_Cf 98
	/*  Californium  */
#define DX_ATN_Es 99
	/*  Einsteinium  */
#define DX_ATN_Fm 100
	/*  Fermium  */
#define DX_ATN_Md 101
	/*  Mendelevium  */
#define DX_ATN_No 102
	/*  Nobelium  */
#define DX_ATN_Lr 103
	/*  Lawrencium  */
#define DX_ATN_MAX 103
	/*  Maximum legal atomic number  */
#define DX_ATN_WILD 0
	/*  Wildcard atom  */
%section "dt_monomer.h"
#define DT_MONOMER_INCLUDED 1
	/* no description */
#define DX_MONO_OK 0
	/*  dt_setbond() succeeded                 */
#define DX_BAD_PARAMETER 1
	/*  Invalid parameter to function          */
#define DX_DUP_CONNECTION_1 2
	/*  Position on m1's SMILES already used   */
#define DX_DUP_CONNECTION_2 3
	/*  Position on m2's SMILES already used   */
#define DX_MISSING_BOND 4
	/*  Removing a bond that isn't there       */
#define DX_ILLEGAL_BONDTYPE 5
	/*  Unknown or illegal bondtype            */
#define DX_NOT_NEIGHBORS 6
	/*  Left/right bond to a non-neighbors     */
#define DX_LEFT_RIGHT_CROSS 7
	/*  Can't crosslink from left/right bonds  */
#define DX_DIFFERENT_PARENTS 8
	/*  Monomers are from different objects    */
#define DX_NO_PARENT 9
	/*  Monomer isn't part of a Multimer       */
#define DX_MISMATCHED_BONDS 10
	/*  Bonds of crosslink don't match         */
#define DX_TOOLKIT_ERROR 11
	/*  Other error; see dt_errors()           */
#define DX_LEFT_BOND 0
	/* no description */
#define DX_RIGHT_BOND -1
	/* no description */
#define DX_BTY_MIXSEP 10
	/* no description */
#define DX_MONO_AND 1
	/* no description */
#define DX_MONO_OR 2
	/* no description */
#define DX_MONO_INFINITY -1
	/* no description */
#define DX_MONO_NOALIAS 0
	/* no description */
#define DX_MONO_ALLOW_ALIAS 1
	/* no description */
#define DX_NOT_MONOMER_OBJECT -1
	/*  Unknown object for dt_badlyformed      */
#define DX_MISSING_CROSSLINK 1
	/*  Not enough crosslinks specified        */
#define DX_ILLEGAL_START_MONOMER 2
	/*  Monomer not valid in 1st position      */
#define DX_END_HAS_RIGHT_BOND 4
	/*  Monomer not valid in last position     */
#define DX_MISMATCHED_RIGHT_BOND 8
	/*  Mismatched bond to right-hand neighbor */
#define DX_MISMATCHED_LEFT_BOND 16
	/*  Mismatched bond to left-hand neighbor  */
#define DX_INVALID_BONDS 1
	/*  Some monomer(set)s incorrectly bonded  */
dt_Handle dt_alloc_monomertable(void);
/* allocate a new monomertable object */
dt_Handle dt_alloc_monomerpat(dt_Handle parenth, dt_Handle mseth,dt_Integer operator,dt_Integer low_limit,dt_Integer high_limit);
/* dt_alloc_monomerpat */
dt_Handle dt_alloc_monomerset(dt_Handle parenth);
/* allocate a new monomerset object */
dt_Handle dt_alloc_multimer(dt_Handle monomertable);
/* allocate a new multimer object */
dt_Handle dt_alloc_varimer(dt_Handle monomertable);
/* allocate a new varimer object */
dt_Handle dt_alloc_varimerpat(dt_Handle parenth);
/* allocate a new varimer pattern object */
%inline %{
#undef dt_define_monomer	/* H HISISIS */
static dt_Handle dt_define_monomer(dt_Handle h,dt_String s,dt_String s2,dt_String s3) { return dt_e_define_monomer(h,strlen(s),s,strlen(s2),s2,strlen(s3),s3); }
%}
/* add a monomer definition to a monomertable */
dt_Handle dt_alloc_mono_path(dt_Handle mvh);
/* allocate a new multimer or varimer based path object	 */
dt_Handle dt_alloc_mono_pathset(dt_Handle mvh);
/* allocate a new pathset object */
%inline %{
#undef dt_getbyval	/* H HIS */
static dt_Handle dt_getbyval(dt_Handle h, dt_String s) { return dt_e_getbyval(h,strlen(s),s); }
%}
/* retrieve a sequence of monomers from a monomertable by SMILES string */
%inline %{
#undef dt_getbysym	/* H HISI */
static dt_Handle dt_getbysym(dt_Handle h, dt_String s,dt_Integer i) { return dt_e_getbysym(h,strlen(s),s,i); }
%}
/* retrieve objects from a monomertable by symbol */
dt_Handle dt_badlyformed(dt_Handle obh, dt_Integer *errcode);
/* test an object for chemical validity */
%inline %{
#undef dt_canchuck	/* S IpH */
static dt_String dt_canchuck(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_canchuck(&i,h)); }
%}
/* retrieve the canonical CHUCKLES string of an object */
dt_Boolean dt_equal(dt_Handle mv1, dt_Handle mv2);
/* test if two objects are equal */
dt_Integer dt_getbond(dt_Handle m1h,  dt_Integer r1,dt_Handle *pm2, dt_Integer *pr2);
/* retrieve the monomer bonded to an object */
dt_Handle dt_intersection(dt_Handle mv1, dt_Handle mv2,dt_Handle mv3);
/* compute the intersection of two multimer or varimer objects */
dt_Handle dt_neighbors(dt_Handle ob);
/* return a sequence of an object's neighbors */
dt_Integer dt_setbond(dt_Handle m1h, dt_Integer r1,dt_Handle m2h, dt_Integer r2,dt_Integer btyp);
/* specify a bond between two sibling objects */
dt_Boolean dt_subset(dt_Handle mv1, dt_Handle mv2);
/* find if an object is a set theoretic subset of another object */
dt_Handle dt_union(dt_Handle mv1, dt_Handle mv2,dt_Handle mv3);
/* form the set union of two objects */
%inline %{
#undef dt_chuckin	/* H HIS */
static dt_Handle dt_chuckin(dt_Handle h, dt_String s) { return dt_e_chuckin(h,strlen(s),s); }
%}
/* interpret a CHUCKLES string */
%inline %{
#undef dt_chortin	/* H HIS */
static dt_Handle dt_chortin(dt_Handle h, dt_String s) { return dt_e_chortin(h,strlen(s),s); }
%}
/* interpret a CHORTLES string */
%inline %{
#undef dt_chartin	/* H HIS */
static dt_Handle dt_chartin(dt_Handle h, dt_String s) { return dt_e_chartin(h,strlen(s),s); }
%}
/* interpret a CHARTS string */
dt_Handle dt_uid2multimer(dt_Handle vh, dt_Integer uid);
/* dt_uid2multimer */
%section "dt_smarts.h"
dt_Handle dt_alloc_pathset( dt_Handle m				     );
/* allocate a new pathset object */
%inline %{
#undef dt_alloc_vbind	/* H IS */
static dt_Handle dt_alloc_vbind(dt_String s) { return dt_e_alloc_vbind(strlen(s),s); }
%}
/* allocate a vector binding */
dt_Handle dt_getval( dt_Handle ob				     );
/* retrieve the value of a binding */
dt_Handle dt_pattern( dt_Handle transform, dt_Integer role       );
/* retrieve a reactant or product pattern from a reaction transform */
dt_Boolean dt_setval( dt_Handle ob, dt_Handle val		     );
/* bind a new value to a vector binding */
%inline %{
#undef dt_smartin	/* H IS */
static dt_Handle dt_smartin(dt_String s) { return dt_e_smartin(strlen(s),s); }
%}
/* interpret a SMARTS string */
%inline %{
#undef dt_smarts_opt	/* S IpISB */
static dt_String dt_smarts_opt(dt_String s2,dt_Boolean b) { dt_Integer i; return swigSaveString(&i,dt_e_smarts_opt(&i,strlen(s2),s2,b)); }
%}
/* optimize a SMARTS expression */
%inline %{
#undef dt_smirkin	/* H IS */
static dt_Handle dt_smirkin(dt_String s) { return dt_e_smirkin(strlen(s),s); }
%}
/* interpret a string as a generic reaction */
dt_Handle dt_transform( dt_Handle transform, dt_Handle som,dt_Integer direction, dt_Integer limit);
/* apply a reaction transform to an object */
dt_Handle dt_utransform( dt_Handle transform, dt_Handle som,dt_Integer direction, dt_Integer limit);
/* transform the coordinates of an object */
dt_Handle dt_xtransform( dt_Handle transform, dt_Handle som,dt_Integer direction, dt_Integer limit);
/* apply a transform to a molecule or sequence */
dt_Handle dt_umatch( dt_Handle ob, dt_Handle mol, dt_Integer ex );
/* match a pattern against an object */
dt_Handle dt_vmatch( dt_Handle ob, dt_Handle mol, dt_Integer ex );
/* match a pattern against an object */
dt_Handle dt_xmatch( dt_Handle ob, dt_Handle mol, dt_Integer ex );
/* match a pattern against an object */
%section "dt_finger.h"
#define DT_FINGER_INCLUDED 1
	/* no description */
#define DX_FP_SET 0
	/* no description */
#define DX_FP_NOT 1
	/* no description */
#define DX_FP_AND 2
	/* no description */
#define DX_FP_OR 3
	/* no description */
#define DX_FP_XOR 4
	/* no description */
dt_Handle dt_fp_allocfp( dt_Integer size                       );
/* allocate a new fingerprint */
dt_Integer dt_fp_bitcount( dt_Handle fph				);
/* count the number of set bits in a fingerprint */
dt_Integer dt_fp_bitvalue( dt_Handle fph, dt_Integer bitno       );
/* retrieve the value of a bit in a fingerprint */
dt_Handle dt_fp_differencefp( dt_Handle obh, dt_Integer minsteps,dt_Integer steps, dt_Integer size     );
/* compute a difference fingerprint for a reaction object */
dt_Real dt_fp_euclid( dt_Handle fpth, dt_Handle fpoh	);
/* compute the euclidean distance between two fingerprints */
dt_Integer dt_fp_fingertest( dt_Handle fpth, dt_Handle fpoh	);
/* test a fingerprint for bitwise inclusion in another fingerprint */
dt_Boolean dt_fp_foldfp( dt_Handle fph, dt_Integer minsize,dt_Real mindensity                    );
/* fold a fingerprint zero or more times */
dt_Handle dt_fp_generatefp( dt_Handle obh, dt_Integer minsteps,dt_Integer steps, dt_Integer size     );
/* generate a fingerprint from an object */
dt_Integer dt_fp_nbits( dt_Handle fph				);
/* retrieve the fingerprint size */
dt_Integer dt_fp_obitcount( dt_Handle fph				);
/* retrieve the number of set bits in an unfolded fingerprint */
dt_Integer dt_fp_obits( dt_Handle fph				);
/* retrieve the unfolded size of a fingerprint */
dt_Handle dt_fp_partfp( dt_Handle part, dt_Handle obh,dt_Integer minsteps, dt_Integer steps,dt_Integer size     );
/* generate a partial fingerprint */
%inline %{
#undef dt_fp_range	/* S IpHIIIp */
static dt_String dt_fp_range(dt_Handle h,dt_Integer i2,dt_Integer i3,dt_Integer *soffset) { dt_Integer i; return swigSaveString(&i,dt_e_fp_range(&i,h,i2,i3,soffset)); }
%}
/* retrieve a range of bits from a fingerprint */
dt_Boolean dt_fp_setbitvalue( dt_Handle fph, dt_Integer bitno,dt_Boolean value);
/* specify the value of a bit in a fingerprint */
dt_Boolean dt_fp_setobitcount( dt_Handle fph, dt_Integer obitcount	);
/* specify the number of bits set in the unfolded fingerprint */
dt_Boolean dt_fp_setobits( dt_Handle fph, dt_Integer obits	);
/* specify the number of bits in the unfolded fingerprint */
%inline %{
#undef dt_fp_setrange	/* I HIIISII */
static dt_Integer dt_fp_setrange(dt_Handle h,dt_Integer i,dt_Integer i2,dt_String s,dt_Integer i3,dt_Integer i4) { return dt_e_fp_setrange(h,i,i2,strlen(s),s,i3,i4); }
%}
/* set a range of bitvalues in a fingerprint */
dt_Real dt_fp_tanimoto( dt_Handle fpth, dt_Handle fpoh	);
/* compute the tanimoto coefficient of two fingerprints */
dt_Real dt_fp_tversky( dt_Handle fpah, dt_Handle fpbh,dt_Real alpha, dt_Real beta           );
/* compute the Tversky coefficient of two fingerprints */
%section "dt_progob.h"
#define DX_PT_NONE 0
	/* no description */
#define DX_PT_CR 1
	/*  The default for newly created programs  */
#define DX_PT_MSGLIST "Qwerty: Say MSGLIST."
	/* no description */
#define DX_PT_HELP "Qwerty: Say HELP."
	/* no description */
#define DX_PT_PROGRAM "Qwerty: Say PROGRAM."
	/* no description */
#define DX_PT_VERSION "Qwerty: Say VERSION."
	/* no description */
#define DX_PT_NOTICE "Qwerty: Say NOTICE."
	/* no description */
#define DX_PT_EOM "Qwerty: Over."
	/* no description */
#define DX_PT_EOT "Qwerty: Over and out."
	/* no description */
dt_Handle dt_alloc_program( dt_Handle ob                    );
/* allocate a new program object */
dt_Handle dt_welcome( dt_Handle prog                  );
/* retrieve a pipetalk welcome message */
dt_Handle dt_converse( dt_Handle prog, dt_Handle msgob );
/* communicate with a program object */
dt_Integer dt_delimiter( dt_Handle prog                  );
/* retrieve the pipetalk delimiter for a program object */
dt_Boolean dt_setdelimiter( dt_Handle prog, dt_Integer value);
/* specify the pipetalk line delimiter */
%section "dt_thor.h"
#define DT_THOR_INCLUDED 1
	/* no description */
#define DX_THOR_USER "thor"
	/*  Privileged user's login name  */
#define DX_INFO_USER "thorinfo"
	/*  Restricted user's login name  */
#define DX_THOR_FIRSTONLY 0
	/* no description */
#define DX_THOR_FINDALL 1
	/* no description */
#define DX_THOR_CACHE_OFF 0x0000
	/*  no caching		      */
#define DX_THOR_CACHE_WRITETHRU 0x0001
	/*  cache hash table, write-thru  */
#define DX_THOR_CACHE_READWRITE 0x0002
	/*  cache hash table	      */
#define DX_THOR_CACHE_WRITETHRU_ALL 0x0003
	/*  cache everything, write-thru  */
#define DX_THOR_CACHE_READWRITE_ALL 0x0004
	/*  cache everything	      */
#define DX_THOR_CACHE_DATA_AND_XREFS 0x0000
	/*  cache TDTs and xrefs	      */
#define DX_THOR_CACHE_DATA_ONLY 0x0100
	/*  only cache primary TDTs	      */
#define DX_THOR_CACHE_XREFS_ONLY 0x0200
	/*  only cache cross references   */
#define DX_THOR_CACHE_NEVER 0
	/*  disable caching  */
#define DX_THOR_CACHE_ON_REQUEST 1
	/*  caching on client request  */
#define DX_THOR_CACHE_ALWAYS 2
	/*  cache whether requested or not  */
#define DX_THOR_INDIRECT_GETONE 0
	/* no description */
#define DX_THOR_INDIRECT_GETALL 1
	/* no description */
#define DX_THOR_DATATYPESDB 0
	/* no description */
#define DX_THOR_INDIRECTDB 1
	/* no description */
#define DX_THOR_MONOMERDB 2
	/* no description */
#define DX_MESSAGE_NONE 0
	/* no description */
#define DX_MESSAGE_NOW 1
	/* no description */
#define DX_MESSAGE_RECORD 2
	/* no description */
#define DX_MESSAGE_FILE 3
	/* no description */
#define DX_THOR_WRITE 0
	/* no description */
#define DX_THOR_WRITE_MERGE 1
	/* no description */
#define DX_THOR_OVERWRITE 2
	/* no description */
#define DX_THOR_MERGE 3
	/* no description */
#define DX_THOR_WRITE_KEEPLOCK 4
	/* no description */
#define DX_THOR_WRITE_MERGE_KEEPLOCK 5
	/* no description */
#define DX_THOR_OVERWRITE_KEEPLOCK 6
	/* no description */
#define DX_THOR_UNLOCK 7
	/* no description */
#define DX_THOR_ROLLBACK 8
	/* no description */
dt_Handle dt_thor_alloc_dataitem(dt_Handle tdth, dt_Handle dtypeh);
/* allocate a new dataitem object in a TDT */
dt_Real dt_thor_autocrunch_limit(dt_Handle dbh, dt_Real limit);
/* specify the trigger for automatic unused space recovery */
dt_Integer dt_thor_cache(dt_Handle dbh, dt_Integer level);
/* specify the caching strategy for a database */
dt_Integer dt_thor_cachecontrol(dt_Handle dbh, dt_Integer when,dt_Integer level);
/* specify the caching strategy for a database */
dt_Integer dt_thor_cachesync(dt_Handle dbh);
/* write all cached data to disk */
%inline %{
#undef dt_thor_createdb	/* H HISII */
static dt_Handle dt_thor_createdb(dt_Handle h, dt_String s,dt_Integer i,dt_Integer i2) { return dt_e_thor_createdb(h,strlen(s),s,i,i2); }
%}
/* create a new THOR database */
dt_Integer dt_thor_crunchdata(dt_Handle dbh);
/* recover unused space from a database */
dt_Integer dt_thor_crunchxref(dt_Handle dbh);
/* dt_thor_crunchxref */
%inline %{
#undef dt_thor_destroy	/* B HISIS */
static dt_Boolean dt_thor_destroy(dt_Handle h,dt_String s,dt_String s2) { return dt_e_thor_destroy(h,strlen(s),s,strlen(s2),s2); }
%}
/* permanently removes a database */
dt_Integer dt_thor_indirect_hint(dt_Handle dbh, dt_Integer hint);
/* specify the "hint" for indirect data fetching */
%inline %{
#undef dt_thor_getauxillarydb	/* S IpHI */
static dt_String dt_thor_getauxillarydb(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_thor_getauxillarydb(&i,h,i2)); }
%}
/* return the name of an auxiliary database */
dt_Integer dt_thor_moveitem(dt_Handle moveh, dt_Handle afterh);
/* move an object within a TDT */
%inline %{
#undef dt_thor_raw_datafield	/* S IpH */
static dt_String dt_thor_raw_datafield(dt_Handle h) { dt_Integer i; return swigSaveString(&i,dt_e_thor_raw_datafield(&i,h)); }
%}
/* return the value of a datafield as a string */
dt_Boolean dt_thor_readonly(dt_Handle dbh);
/* dt_thor_readonly */
%inline %{
#undef dt_thor_server	/* H ISISISISIp */
static dt_Handle dt_thor_server(dt_String s,dt_String s2,dt_String s3,dt_String s4,dt_Integer *isnew) { return dt_e_thor_server(strlen(s),s,strlen(s2),s2,strlen(s3),s3,strlen(s4),s4,isnew); }
%}
/* connect to a server */
%inline %{
#undef dt_thor_setauxillarydb	/* B HIIS */
static dt_Boolean dt_thor_setauxillarydb(dt_Handle h,dt_Integer i,dt_String s) { return dt_e_thor_setauxillarydb(h,i,strlen(s),s); }
%}
/* modify the name of an auxiliary database */
%inline %{
#undef dt_thor_setreadonly	/* B HISB */
static dt_Boolean dt_thor_setreadonly(dt_Handle h,dt_String s,dt_Boolean b) { return dt_e_thor_setreadonly(h,strlen(s),s,b); }
%}
/* manipulate the "readonly" state of a database */
%inline %{
#undef dt_thor_settdtlocking	/* B HISB */
static dt_Boolean dt_thor_settdtlocking(dt_Handle h,dt_String s,dt_Boolean b) { return dt_e_thor_settdtlocking(h,strlen(s),s,b); }
%}
/* manipulate the "record locking" property of a database */
%inline %{
#undef dt_thor_str2tdt	/* H HISI */
static dt_Handle dt_thor_str2tdt(dt_Handle h, dt_String s,dt_Integer i) { return dt_e_thor_str2tdt(h,strlen(s),s,i); }
%}
/* convert a string into a TDT */
%inline %{
#undef dt_thor_tdt2str	/* S IpHI */
static dt_String dt_thor_tdt2str(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_thor_tdt2str(&i,h,i2)); }
%}
/* convert a TDT into a string representation */
dt_Boolean dt_thor_tdtlocking(dt_Handle dbh);
/* determine if record locking is enforced for a database */
%inline %{
#undef dt_thor_tdtget	/* H HHISIIp */
static dt_Handle dt_thor_tdtget(dt_Handle h,dt_Handle h2,dt_String s,dt_Integer i,dt_Integer *isnew) { return dt_e_thor_tdtget(h,h2,strlen(s),s,i,isnew); }
%}
/* retrieve a TDT from a database */
%inline %{
#undef dt_thor_tdtget_raw	/* H HISISB */
static dt_Handle dt_thor_tdtget_raw(dt_Handle h,dt_String s,dt_String s2,dt_Boolean b) { return dt_e_thor_tdtget_raw(h,strlen(s),s,strlen(s2),s2,b); }
%}
/* retrieve a TDT from a database as a string */
%inline %{
#undef dt_thor_tdtlockedby	/* S IpHIS */
static dt_String dt_thor_tdtlockedby(dt_Handle h,dt_String s2) { dt_Integer i; return swigSaveString(&i,dt_e_thor_tdtlockedby(&i,h,strlen(s2),s2)); }
%}
/* determine who locked a TDT */
dt_Handle dt_thor_tdtmerge(dt_Handle t1h, dt_Handle t2h);
/* merge one TDT with another */
dt_Integer dt_thor_tdtremove(dt_Handle tdth);
/* remove a TDT from a database */
%inline %{
#undef dt_thor_tdtremove_raw	/* I HISIS */
static dt_Integer dt_thor_tdtremove_raw(dt_Handle h,dt_String s,dt_String s2) { return dt_e_thor_tdtremove_raw(h,strlen(s),s,strlen(s2),s2); }
%}
/* remove a TDT from a database */
dt_Integer dt_thor_tdtput(dt_Handle tdth, dt_Integer how);
/* insert a TDT into a database */
%inline %{
#undef dt_thor_tdtput_raw	/* I HISI */
static dt_Integer dt_thor_tdtput_raw(dt_Handle h,dt_String s,dt_Integer i) { return dt_e_thor_tdtput_raw(h,strlen(s),s,i); }
%}
/* insert a string into a database */
dt_Integer dt_thor_tdtrevise(dt_Handle tdth);
/* rewrite a TDT in preparation for storage */
%inline %{
#undef dt_thor_xrefget	/* H HHISIp */
static dt_Handle dt_thor_xrefget(dt_Handle h,dt_Handle h2,dt_String s,dt_Integer *iserror) { return dt_e_thor_xrefget(h,h2,strlen(s),s,iserror); }
%}
/* dt_thor_xrefget */
%section "dt_merlin.h"
#define DT_MERLIN_INCLUDED 1
	/* no description */
#define DX_TAG_SIMILARITY "SIMILARITY"
	/* no description */
#define DX_TAG_SMILES "$SMI"
	/* no description */
#define DX_TAG_ISOSMILES "$ISM"
	/* no description */
#define DX_TAG_FINGERPRINT "FP"
	/* no description */
#define DX_FUNC_FIRST 0
	/* no description */
#define DX_FUNC_LAST 1
	/* no description */
#define DX_FUNC_MIN 2
	/* no description */
#define DX_FUNC_MAX 3
	/* no description */
#define DX_FUNC_LONGEST 4
	/* no description */
#define DX_FUNC_SHORTEST 5
	/* no description */
#define DX_FUNC_ALL 6
	/* no description */
#define DX_FUNC_AVG 7
	/* no description */
#define DX_FUNC_STDDEV 8
	/* no description */
#define DX_FUNC_COUNT 9
	/* no description */
#define DM_NFUNCS 10
	/*  number of DX_FUNC_ definitions  */
#define DX_SORT_ASC 0
	/*  straight ASCII comparison	      */
#define DX_SORT_ANC 1
	/*  ignore case			      */
#define DX_SORT_ANP 2
	/*  ignore whitespace		      */
#define DX_SORT_ANW 3
	/*  ignore punctuation		      */
#define DX_SORT_ANCP 4
	/*  ignore case, punctuation	      */
#define DX_SORT_ANCW 5
	/*  ignore case, whitespace	      */
#define DX_SORT_ANPW 6
	/*  ignore punctuation, whitespace     */
#define DX_SORT_ANCPW 7
	/*  ignore case, punct, whitespace     */
#define DX_SORT_AAZ 8
	/*  ignore all except a-z and A-Z      */
#define DX_SORT_NUM 9
	/*  numeric sort			      */
#define DX_SORT_NAB 10
	/*  absolute-value numeric sort	      */
#define DX_SORT_CAS 11
	/*  sort by Chem. Abstracts number     */
#define DX_SORT_MFM 12
	/*  sort by molecular formula	      */
#define DX_SORT_LEN 13
	/*  sort by length		      */
#define DM_NSORTS 14
	/*  number of DX_SORT_ definitions     */
#define DX_ACTION_NEW_LIST 0
	/* no description */
#define DX_ACTION_ADD_HITS 1
	/* no description */
#define DX_ACTION_ADD_NONHITS 2
	/* no description */
#define DX_ACTION_DEL_HITS 3
	/* no description */
#define DX_ACTION_DEL_NONHITS 4
	/* no description */
#define DX_ACTION_NEXT_HIT 5
	/* no description */
#define DX_ACTION_NEXT_NONHIT 6
	/* no description */
#define DM_NACTIONS 7
	/*  number of DX_ACTION_ definitions  */
#define DX_STRING_ASCII 0
	/*  ascii match                        */
#define DX_STRING_NC 1
	/*  ignore case                        */
#define DX_STRING_NW 2
	/*  ignore whitespace                  */
#define DX_STRING_NP 3
	/*  ignore punctuation                 */
#define DX_STRING_NCW 4
	/*  ignore case, whitespace            */
#define DX_STRING_NCP 5
	/*  ignore case, punctuation           */
#define DX_STRING_NPW 6
	/*  ignore punctuation, whitespace     */
#define DX_STRING_NCPW 7
	/*  ignore case, punct,  whitespace    */
#define DX_STRING_REGEXP 8
	/*  search using regular expression    */
#define DX_STRING_APPROX 9
	/*  search using approximate matching  */
#define DM_NSTRINGS 10
	/*  number of DX_SSTRING_ definitions  */
#define DX_SUPER_SMILES 0
	/*  fast search SMILES & Fingerprints  */
#define DX_SUPER_SMARTS 1
	/*  SMARTS search (no screening)	      */
#define DX_SUPER_CHARTS 2
	/*  Searching Mult/Varimers w/ CHARTS  */
#define DX_SUPER_SMILESPART 3
	/*  fast search SMILES use FPP<>       */
#define DX_SUPER_SMARTSPART 4
	/*  SMARTS search use FPP<>	      */
#define DM_NSUPERS 5
	/*  number of DX_SUPER_ search types   */
#define DX_SUBSTRUCT_SMILES 0
	/*  for consistency tho' just one      */
#define DM_NSUBSTRUCTS 1
	/*  number of DX_SUBSTRUCT_ searches   */
#define DX_SIMILAR_TANIMOTO 0
	/*  Tanimoto coefficient		      */
#define DX_SIMILAR_EUCLIDIAN 1
	/*  Euclidian distance		      */
#define DX_SIMILAR_TVERSKY 2
	/*  Tversky similarity		      */
#define DM_NSIMILAR 3
	/*  number of similarity searches      */
#define DX_STATUS_IN_PROGRESS 0
	/*  not finished, task in progress     */
#define DX_STATUS_DONE 1
	/*  finished search, target found      */
#define DX_STATUS_NOT_FOUND 2
	/*  finished search, target not found  */
#define DX_STATUS_ERROR 3
	/*  error,  operation not performed    */
%inline %{
#undef dt_mer_server	/* H ISISISISIp */
static dt_Handle dt_mer_server(dt_String s,dt_String s2,dt_String s3,dt_String s4,dt_Integer *isnew) { return dt_e_mer_server(strlen(s),s,strlen(s2),s2,strlen(s3),s3,strlen(s4),s4,isnew); }
%}
/* connect to a server */
%inline %{
#undef dt_mer_action2name	/* S IpHI */
static dt_String dt_mer_action2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_action2name(&i,h,i2)); }
%}
/* return a string name for a Merlin action */
%inline %{
#undef dt_mer_function2name	/* S IpHI */
static dt_String dt_mer_function2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_function2name(&i,h,i2)); }
%}
/* return a string name for a Merlin function */
%inline %{
#undef dt_mer_search2name	/* S IpHI */
static dt_String dt_mer_search2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_search2name(&i,h,i2)); }
%}
/* return a string name for a Merlin search capability */
%inline %{
#undef dt_mer_similar2name	/* S IpHI */
static dt_String dt_mer_similar2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_similar2name(&i,h,i2)); }
%}
/* return a string name for a similarity measure */
%inline %{
#undef dt_mer_sort2name	/* S IpHI */
static dt_String dt_mer_sort2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_sort2name(&i,h,i2)); }
%}
/* return a string name for a Merlin sort */
%inline %{
#undef dt_mer_subselect2name	/* S IpHI */
static dt_String dt_mer_subselect2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_subselect2name(&i,h,i2)); }
%}
/* return a string name for a Merlin substructure select */
%inline %{
#undef dt_mer_superselect2name	/* S IpHI */
static dt_String dt_mer_superselect2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_superselect2name(&i,h,i2)); }
%}
/* return a string name for a Merlin superstructure select */
%inline %{
#undef dt_mer_progob2name	/* S IpHI */
static dt_String dt_mer_progob2name(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_progob2name(&i,h,i2)); }
%}
/* return the string name of a program object */
dt_Integer dt_mer_nactions(dt_Handle serverh);
/* retrieve the number of action capabilities */
dt_Integer dt_mer_nfunctions(dt_Handle serverh);
/* retrieve the number of column function capabilities */
dt_Integer dt_mer_nsearches(dt_Handle serverh);
/* retrieve the number of search capabilities */
dt_Integer dt_mer_nsimilars(dt_Handle serverh);
/* retrieve the number of similarity capabilities */
dt_Integer dt_mer_nsorts(dt_Handle serverh);
/* retrieve the number of sort capabilities */
dt_Integer dt_mer_nsubselects(dt_Handle serverh);
/* retrieve the number of subselection capabilities */
dt_Integer dt_mer_nsuperselects(dt_Handle serverh);
/* get the number of superstructure capabilities */
dt_Integer dt_mer_nprogobs(dt_Handle serverh);
/* retrieve the number of program objects */
dt_Integer dt_mer_getnitems(dt_Handle pool, dt_Handle dtype);
/* retrieve the number of dataitems of given datatype */
dt_Handle dt_mer_alloc_column(dt_Handle  poolh,dt_Handle  ftypeh,dt_Integer functype);
/* create a column of data in a pool */
dt_Integer dt_mer_function(dt_Handle colh);
/* retrieves the function used to create a column */
dt_Handle dt_mer_alloc_hitlist(dt_Handle poolh);
/* create a hitlist object */
dt_Integer dt_mer_clear(dt_Handle hith);
/* clears a hitlist */
dt_Integer dt_mer_combinehitlists(dt_Handle hith1, dt_Handle hh2,dt_Integer action);
/* combine two hitlists */
dt_Integer dt_mer_hit2id(dt_Handle hith, dt_Integer ihit);
/* convert a hitlist index to a row identifier */
dt_Integer dt_mer_id2hit(dt_Handle hith, dt_Integer id);
/* convert a row identifier to a hitlist index */
dt_Integer dt_mer_invert(dt_Handle hith);
/* complement a hitlist with respect to a database */
dt_Integer dt_mer_length(dt_Handle hith);
/* return the number of items in a hitlist */
dt_Integer dt_mer_mvbottom(dt_Handle hith, dt_Integer ihit);
/* move an item to the bottom of a hitlist */
dt_Integer dt_mer_mvtop(dt_Handle hith, dt_Integer ihit);
/* move an item to the top of a hitlist */
dt_Integer dt_mer_native(dt_Handle hith);
/* reset the row order of a hitlist to native order */
dt_Integer dt_mer_reset(dt_Handle hith);
/* reset the row order of a hitlist to native order */
dt_Integer dt_mer_reverse(dt_Handle hith);
/* reverse the row order of a hitlist */
dt_Integer dt_mer_sethits(dt_Handle hith, dt_Handle ch,dt_Handle sq);
/* explicitly specify additional hits for a hitlist */
dt_Integer dt_mer_zapabove(dt_Handle hith, dt_Integer ihit);
/* delete rows before a specified row in a hitlist */
dt_Integer dt_mer_zapbelow(dt_Handle hith, dt_Integer ihit);
/* delete rows beyond a specified row in a hitlist */
dt_Integer dt_mer_zapna(dt_Handle hith, dt_Handle colh);
/* delete rows with no data from a hitlist */
dt_Integer dt_mer_zapnonunique(dt_Handle hith, dt_Handle colh);
/* delete redundant rows from a hitlist */
dt_Integer dt_mer_sort(dt_Handle hith,dt_Handle  colh,dt_Integer sort,dt_Integer ascending,dt_Integer *pret_status);
/* initiate a sort */
/* two additional dt_mer_strsearch entries to handle invalid string */
%inline %{
#undef dt_mer_strsearch_range	/* I HHIIIIpISIS */
static dt_Integer dt_mer_strsearch_range(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s,dt_String s2) { return dt_e_mer_strsearch(h,h2,i,i2,i3,pstatus,strlen(s),s,strlen(s2),s2); }
%}
/* search a merlin string field for a range of values */
%inline %{
#undef dt_mer_strsearch_match	/* I HHIIIIpISIS */
static dt_Integer dt_mer_strsearch_match(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s) { return dt_e_mer_strsearch(h,h2,i,i2,i3,pstatus,strlen(s),s,-1,NULL); }
%}
/* search a merlin string field for a match to a value */
%inline %{
#undef dt_mer_strsearch	/* I HHIIIIpISIS */
static dt_Integer dt_mer_strsearch(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s,dt_String s2) { return dt_e_mer_strsearch(h,h2,i,i2,i3,pstatus,strlen(s),s,strlen(s2),s2); }
%}
/* initiate a string search */
dt_Integer dt_mer_numsearch(dt_Handle hith,dt_Handle colh,dt_Integer action,dt_Integer find_next,dt_Integer *ret_status,float low,float high);
/* initiate a numeric search */
%inline %{
#undef dt_mer_subselect	/* I HHIIIIpIS */
static dt_Integer dt_mer_subselect(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s) { return dt_e_mer_subselect(h,h2,i,i2,i3,pstatus,strlen(s),s); }
%}
/* initiate a substructure search */
%inline %{
#undef dt_mer_superselect	/* I HHIIIIpIS */
static dt_Integer dt_mer_superselect(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s) { return dt_e_mer_superselect(h,h2,i,i2,i3,pstatus,strlen(s),s); }
%}
/* initiate a superstructure search */
%inline %{
#undef dt_mer_supermixtureselect	/* I HHIIIIpIS */
static dt_Integer dt_mer_supermixtureselect(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s) { return dt_e_mer_supermixtureselect(h,h2,i,i2,i3,pstatus,strlen(s),s); }
%}
/* dt_mer_supermixtureselect */
%inline %{
#undef dt_mer_submixtureselect	/* I HHIIIIpIS */
static dt_Integer dt_mer_submixtureselect(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s) { return dt_e_mer_submixtureselect(h,h2,i,i2,i3,pstatus,strlen(s),s); }
%}
/* dt_mer_submixtureselect */
%inline %{
#undef dt_mer_similarselect	/* I HHIIIIpISRRR */
static dt_Integer dt_mer_similarselect(dt_Handle h,dt_Handle h2,dt_Integer i,dt_Integer i2,dt_Integer i3,dt_Integer *pstatus,dt_String s,dt_Real r,dt_Real r2,dt_Real r3) { return dt_e_mer_similarselect(h,h2,i,i2,i3,pstatus,strlen(s),s,r,r2,r3); }
%}
/* initiate a similarity search */
dt_Integer dt_mer_progob_compare(dt_Handle hith,dt_Handle target_colh,dt_Handle results_colh,dt_Integer iprogob,dt_Handle pattern_bin,dt_Handle parameters,dt_Integer *pstatus);
/* invoke a program object comparison */
dt_Handle dt_mer_progob_compute(dt_Handle poolh,dt_Integer iprogob,dt_Handle strobj,dt_Handle parms);
/* invoke a program object computation */
dt_Handle dt_mer_progob_computeparams(dt_Handle poolh, dt_Integer iprogob);
/* retrieve parameter names and default values for a program object computation */
dt_Handle dt_mer_progob_compareparams(dt_Handle poolh, dt_Integer iprogob);
/* retrieve parameter names and default values for a program object comparison */
%inline %{
#undef dt_mer_cellvalue	/* S IpHHI */
static dt_String dt_mer_cellvalue(dt_Handle h,dt_Handle h2,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_cellvalue(&i,h,h2,i2)); }
%}
/* retrieve the value of a cell in a hitlist row and column */
%inline %{
#undef dt_mer_getdata	/* S IpHIHI */
static dt_String dt_mer_getdata(dt_Handle h,dt_Integer i2,dt_Handle h2,dt_Integer i3) { dt_Integer i; return swigSaveString(&i,dt_e_mer_getdata(&i,h,i2,h2,i3)); }
%}
/* retrieve a field item from a row of a hitlist */
%inline %{
#undef dt_mer_getroot	/* S IpHI */
static dt_String dt_mer_getroot(dt_Handle h,dt_Integer i2) { dt_Integer i; return swigSaveString(&i,dt_e_mer_getroot(&i,h,i2)); }
%}
/* retrieve the root identifier of a hitlist item */
dt_Integer dt_mer_defaultsort( dt_Handle colh			);
/* retrieves the default sort for a column */
dt_Boolean dt_mer_sortapplies( dt_Handle colh,    dt_Integer sort	);
/* tests if a sort can be applied to a column */
dt_Boolean dt_mer_funcapplies( dt_Handle ftypeh,  dt_Integer function);
/* tests if a function can be applied to a column */
%if defined(SWIGPYTHON)
%section "dt_depict.h"
dt_Handle dt_alloc_conformation(dt_Handle mh                              );
/* allocate a new conformation object */
dt_Handle dt_alloc_depiction(dt_Handle mh                              );
/* allocate a new depiction object */
dt_Integer dt_bondstyle(dt_Handle deph, dt_Handle ah, dt_Handle bh);
/* retrieve the style of a bond in a depiction */
dt_Integer dt_calcxy(dt_Handle ob                              );
/* compute planar coordinates for a depiction */
dt_Boolean dt_compressed(dt_Handle ob                              );
/* retrieve the compressed attribute of a depiction */
dt_Boolean dt_depict(dt_Handle ob                              );
/* dt_depict */
dt_Integer dt_frame(dt_Handle ob                              );
/* retrieve the frame attribute of a depiction */
dt_Integer dt_framega(dt_Handle ob                              );
/* retrieve the graphics attribute of the depiction frame */
dt_Integer dt_ga(dt_Handle ob, dt_Handle ob2               );
/* retrieve the graphics attribute of an object */
/* retrieve the coordinates of an object */
dt_Integer dt_isomeric(dt_Handle ob                              );
/* retrieve the isomeric attribute of a depiction */
%inline %{
#undef dt_label1	/* S IpHH */
static dt_String dt_label1(dt_Handle h,dt_Handle h2) { dt_Integer i; return swigSaveString(&i,dt_e_label1(&i,h,h2)); }
%}
/* retrieve a string label */
dt_Integer dt_label1ga(dt_Handle ob, dt_Handle ob2               );
/* retrieve the graphics attribute of a string label */
%inline %{
#undef dt_label2	/* S IpHH */
static dt_String dt_label2(dt_Handle h,dt_Handle h2) { dt_Integer i; return swigSaveString(&i,dt_e_label2(&i,h,h2)); }
%}
/* retrieve a string label */
dt_Integer dt_label2ga(dt_Handle ob, dt_Handle ob2               );
/* retrieve the graphics attribute of a string label */
dt_Integer dt_orient(dt_Handle ob                              );
/* retrieve the orientation property of a depiction */
dt_Integer dt_project(dt_Handle ob, dt_Handle conf              );
/* project the coordinates of an object into a depiction plane */
dt_Integer dt_rotate(dt_Handle ob, dt_Real x, dt_Real y,dt_Real z, dt_Real theta		     );
/* rotate the coordinates of an object */
dt_Integer dt_scale(dt_Handle ob, dt_Real cx, dt_Real cy,dt_Real cz				     );
/* scale the coordinates of an object */
dt_Integer dt_schematic(dt_Handle ob                              );
/* retrieve the schematic attribute of a depiction */
dt_Integer dt_setbondstyles(dt_Handle deph                            );
/* specify the chiral bond style for a depiction */
dt_Integer dt_setcompressed(dt_Handle ob, dt_Integer v                );
/* specify the compressed attribute of a depiction */
dt_Integer dt_setcoord(dt_Handle ob, dt_Handle ah,dt_Real x, dt_Real y, dt_Real z            );
/* specify the coordinates of an object */
dt_Integer dt_setframe(dt_Handle ob, dt_Integer boo              );
/* specify the frame attribute of a depiction */
dt_Integer dt_setframega(dt_Handle ob, dt_Integer ga               );
/* specify the graphics attribute for the frame of a depiction */
dt_Integer dt_setga(dt_Handle ob, dt_Handle ob2,dt_Integer ga       );
/* specify the graphics attribute of an object in a depiction */
dt_Integer dt_setisomeric(dt_Handle ob, dt_Integer v                );
/* specify the isomeric attribute for a depiction */
dt_Boolean dt_setlabel1(dt_Handle ob, dt_Handle ob2, dt_String lab);
/* specify the label for an object in a depiction */
dt_Boolean dt_setlabel2(dt_Handle ob, dt_Handle ob2, dt_String lab);
/* specify the label of an object in a depiction */
dt_Integer dt_setlabel1ga(dt_Handle ob, dt_Handle ob2, dt_Integer ga);
/* specify the label graphic attribute for an object in a depiction */
dt_Integer dt_setlabel2ga(dt_Handle ob, dt_Handle ob2, dt_Integer ga);
/* specify the label graphics attribute for an object in a depiction */
dt_Integer dt_setorient(dt_Handle ob, dt_Integer v                );
/* specify the orient attribute of a depiction */
dt_Integer dt_setschematic(dt_Handle ob, dt_Integer v                );
/* specify the schematic attribute of a depiction */
dt_Integer dt_translate(dt_Handle ob, dt_Real dx, dt_Real dy,dt_Real dz				     );
/* translate the coordinates of an object */
dt_Integer dt_zerocoord(dt_Handle ob                              );
/* zero the coordinates of an object */
#define DX_ORIENT_NONE (0x000)
	/* no description */
#define DX_ORIENT_AUTO (0x001)
	/* no description */
#define DX_ORIENT_WILD (0x002)
	/* no description */
#define DX_EDGE_SIMPLE (0x000)
	/* no description */
#define DX_EDGE_TEE (0x001)
	/* no description */
#define DX_EDGE_TEE_IN (0x002)
	/* no description */
#define DX_EDGE_TEE_OUT (0x004)
	/* no description */
#define DX_EDGE_TRI (0x008)
	/* no description */
#define DX_EDGE_TRI_IN (0x010)
	/* no description */
#define DX_EDGE_TRI_OUT (0x020)
	/* no description */
#define DX_EDGE_HASH (0x040)
	/* no description */
#define DX_EDGE_DATIVE (0x080)
	/* no description */
#define DX_EDGE_IS_TEE_IN (DX_EDGE_TEE | DX_EDGE_TEE_IN)
	/* no description */
#define DX_EDGE_IS_TEE_OUT (DX_EDGE_TEE | DX_EDGE_TEE_OUT)
	/* no description */
#define DX_EDGE_IS_TRI_IN (DX_EDGE_TRI | DX_EDGE_TRI_IN)
	/* no description */
#define DX_EDGE_IS_TRI_OUT (DX_EDGE_TRI | DX_EDGE_TRI_OUT)
	/* no description */
#define DX_EDGE_IS_DIAMOND (DX_EDGE_TRI | DX_EDGE_TRI_IN  | DX_EDGE_TRI_OUT)
	/* no description */
#define DX_EDGE_IS_BOWTIE (DX_EDGE_TRI)
	/* no description */
#define DX_EDGE_IS_HASH_IN (DX_EDGE_TRI | DX_EDGE_TRI_IN  | DX_EDGE_HASH)
	/* no description */
#define DX_EDGE_IS_HASH_OUT (DX_EDGE_TRI | DX_EDGE_TRI_OUT | DX_EDGE_HASH)
	/* no description */
#define DX_EDGE_IS_DATIVE (DX_EDGE_DATIVE)
	/* no description */
%section "dl_ga.h"
#define DL_COLORMODE_MONOCHROME 0
	/* no description */
#define DL_COLORMODE_GRAYSCALE 1
	/* no description */
#define DL_COLORMODE_STDCOLOR 2
	/* no description */
#define DL_COLORMODE_BOW -3
	/*  black on white  */
#define DL_COLORMODE_WOB -4
	/*  white on black  */
#define DL_COLORMODE_COW -5
	/*  color on white  */
#define DL_COLORMODE_COB -6
	/*  color on black  */
#define DL_LINESTYLE_DEFAULT 0
	/* no description */
#define DL_LINESTYLE_SOLID 1
	/* no description */
#define DL_LINESTYLE_DOTTED 2
	/* no description */
#define DL_LINESTYLE_DASHED 3
	/* no description */
#define DL_LINEWIDTH_DEFAULT 0
	/* no description */
#define DL_LINEWIDTH_THIN 1
	/* no description */
#define DL_LINEWIDTH_NORMAL 2
	/* no description */
#define DL_LINEWIDTH_WIDE 3
	/* no description */
#define DL_LINEWIDTH_EXTRAWIDE 4
	/* no description */
#define DL_GA_LIMIT 205
	/* no description */
#define DL_GA_GENERAL_COUNT 13
	/* no description */
#define DL_GA_DEFAULT 0
	/* no description */
#define DL_GA_NORMAL 1
	/* no description */
#define DL_GA_BACKGROUND 2
	/* no description */
#define DL_GA_BORDER 3
	/* no description */
#define DL_GA_DATA 4
	/* no description */
#define DL_GA_HIGHLIGHT 5
	/* no description */
#define DL_GA_MUTED 6
	/* no description */
#define DL_GA_TEXTLABEL 7
	/* no description */
#define DL_GA_ATOMLABEL 8
	/* no description */
#define DL_GA_BONDLABEL 9
	/* no description */
#define DL_GA_NOTE 10
	/* no description */
#define DL_GA_WARNING 11
	/* no description */
#define DL_GA_ERROR 12
	/* no description */
#define DL_GA_PAPER 13
	/* no description */
#define DL_GA_NOTPAPER 14
	/* no description */
#define DL_GA_TEMPER_COUNT 11
	/* no description */
#define DL_GA_TEMPER_0 20
	/* no description */
#define DL_GA_TEMPER_1 21
	/* no description */
#define DL_GA_TEMPER_2 22
	/* no description */
#define DL_GA_TEMPER_3 23
	/* no description */
#define DL_GA_TEMPER_4 24
	/* no description */
#define DL_GA_TEMPER_5 25
	/* no description */
#define DL_GA_TEMPER_6 26
	/* no description */
#define DL_GA_TEMPER_7 27
	/* no description */
#define DL_GA_TEMPER_8 28
	/* no description */
#define DL_GA_TEMPER_9 29
	/* no description */
#define DL_GA_TEMPER_10 30
	/* no description */
#define DL_GA_GRAY_COUNT 11
	/* no description */
#define DL_GA_GRAY_0 31
	/* no description */
#define DL_GA_GRAY_10 32
	/* no description */
#define DL_GA_GRAY_20 33
	/* no description */
#define DL_GA_GRAY_30 34
	/* no description */
#define DL_GA_GRAY_40 35
	/* no description */
#define DL_GA_GRAY_50 36
	/* no description */
#define DL_GA_GRAY_60 37
	/* no description */
#define DL_GA_GRAY_70 38
	/* no description */
#define DL_GA_GRAY_80 39
	/* no description */
#define DL_GA_GRAY_90 40
	/* no description */
#define DL_GA_GRAY_100 41
	/* no description */
#define DL_GA_CHARGE_COUNT 11
	/* no description */
#define DL_GA_CHARGE_5N 42
	/* no description */
#define DL_GA_CHARGE_4N 43
	/* no description */
#define DL_GA_CHARGE_3N 44
	/* no description */
#define DL_GA_CHARGE_2N 45
	/* no description */
#define DL_GA_CHARGE_1N 46
	/* no description */
#define DL_GA_CHARGE_0 47
	/* no description */
#define DL_GA_CHARGE_1P 48
	/* no description */
#define DL_GA_CHARGE_2P 49
	/* no description */
#define DL_GA_CHARGE_3P 50
	/* no description */
#define DL_GA_CHARGE_4P 51
	/* no description */
#define DL_GA_CHARGE_5P 52
	/* no description */
#define DL_GA_ENUM_COUNT 8
	/* no description */
#define DL_GA_ENUM_0 53
	/* no description */
#define DL_GA_ENUM_1 54
	/* no description */
#define DL_GA_ENUM_2 55
	/* no description */
#define DL_GA_ENUM_3 56
	/* no description */
#define DL_GA_ENUM_4 57
	/* no description */
#define DL_GA_ENUM_5 58
	/* no description */
#define DL_GA_ENUM_6 59
	/* no description */
#define DL_GA_ENUM_7 60
	/* no description */
#define DL_GA_ELEM_COUNT 106
	/* no description */
#define DL_GA_ELEM_WILD 100
	/* no description */
#define DL_GA_ELEM_H 101
	/* no description */
#define DL_GA_ELEM_HE 102
	/* no description */
#define DL_GA_ELEM_LI 103
	/* no description */
#define DL_GA_ELEM_BE 104
	/* no description */
#define DL_GA_ELEM_B 105
	/* no description */
#define DL_GA_ELEM_C 106
	/* no description */
#define DL_GA_ELEM_N 107
	/* no description */
#define DL_GA_ELEM_O 108
	/* no description */
#define DL_GA_ELEM_F 109
	/* no description */
#define DL_GA_ELEM_NE 110
	/* no description */
#define DL_GA_ELEM_NA 111
	/* no description */
#define DL_GA_ELEM_MG 112
	/* no description */
#define DL_GA_ELEM_AL 113
	/* no description */
#define DL_GA_ELEM_SI 114
	/* no description */
#define DL_GA_ELEM_P 115
	/* no description */
#define DL_GA_ELEM_S 116
	/* no description */
#define DL_GA_ELEM_CL 117
	/* no description */
#define DL_GA_ELEM_AR 118
	/* no description */
#define DL_GA_ELEM_K 119
	/* no description */
#define DL_GA_ELEM_CA 120
	/* no description */
#define DL_GA_ELEM_SC 121
	/* no description */
#define DL_GA_ELEM_TI 122
	/* no description */
#define DL_GA_ELEM_V 123
	/* no description */
#define DL_GA_ELEM_CR 124
	/* no description */
#define DL_GA_ELEM_MN 125
	/* no description */
#define DL_GA_ELEM_FE 126
	/* no description */
#define DL_GA_ELEM_CO 127
	/* no description */
#define DL_GA_ELEM_NI 128
	/* no description */
#define DL_GA_ELEM_CU 129
	/* no description */
#define DL_GA_ELEM_ZN 130
	/* no description */
#define DL_GA_ELEM_GA 131
	/* no description */
#define DL_GA_ELEM_GE 132
	/* no description */
#define DL_GA_ELEM_AS 133
	/* no description */
#define DL_GA_ELEM_SE 134
	/* no description */
#define DL_GA_ELEM_BR 135
	/* no description */
#define DL_GA_ELEM_KR 136
	/* no description */
#define DL_GA_ELEM_RB 137
	/* no description */
#define DL_GA_ELEM_SR 138
	/* no description */
#define DL_GA_ELEM_Y 139
	/* no description */
#define DL_GA_ELEM_ZR 140
	/* no description */
#define DL_GA_ELEM_NB 141
	/* no description */
#define DL_GA_ELEM_MO 142
	/* no description */
#define DL_GA_ELEM_TC 143
	/* no description */
#define DL_GA_ELEM_RU 144
	/* no description */
#define DL_GA_ELEM_RH 145
	/* no description */
#define DL_GA_ELEM_PD 146
	/* no description */
#define DL_GA_ELEM_AG 147
	/* no description */
#define DL_GA_ELEM_CD 148
	/* no description */
#define DL_GA_ELEM_IN 149
	/* no description */
#define DL_GA_ELEM_SN 150
	/* no description */
#define DL_GA_ELEM_SB 151
	/* no description */
#define DL_GA_ELEM_TE 152
	/* no description */
#define DL_GA_ELEM_I 153
	/* no description */
#define DL_GA_ELEM_XE 154
	/* no description */
#define DL_GA_ELEM_CS 155
	/* no description */
#define DL_GA_ELEM_BA 156
	/* no description */
#define DL_GA_ELEM_LA 157
	/* no description */
#define DL_GA_ELEM_HF 158
	/* no description */
#define DL_GA_ELEM_TA 159
	/* no description */
#define DL_GA_ELEM_W 160
	/* no description */
#define DL_GA_ELEM_RE 161
	/* no description */
#define DL_GA_ELEM_OS 162
	/* no description */
#define DL_GA_ELEM_IR 163
	/* no description */
#define DL_GA_ELEM_PT 164
	/* no description */
#define DL_GA_ELEM_AU 165
	/* no description */
#define DL_GA_ELEM_HG 166
	/* no description */
#define DL_GA_ELEM_TL 167
	/* no description */
#define DL_GA_ELEM_PB 168
	/* no description */
#define DL_GA_ELEM_BI 169
	/* no description */
#define DL_GA_ELEM_PO 170
	/* no description */
#define DL_GA_ELEM_AT 171
	/* no description */
#define DL_GA_ELEM_RN 172
	/* no description */
#define DL_GA_ELEM_FR 173
	/* no description */
#define DL_GA_ELEM_RA 174
	/* no description */
#define DL_GA_ELEM_AC 175
	/* no description */
#define DL_GA_ELEM_RF 176
	/* no description */
#define DL_GA_ELEM_HA 177
	/* no description */
#define DL_GA_ELEM_CE 178
	/* no description */
#define DL_GA_ELEM_PR 179
	/* no description */
#define DL_GA_ELEM_ND 180
	/* no description */
#define DL_GA_ELEM_PM 181
	/* no description */
#define DL_GA_ELEM_SM 182
	/* no description */
#define DL_GA_ELEM_EU 183
	/* no description */
#define DL_GA_ELEM_GD 184
	/* no description */
#define DL_GA_ELEM_TB 185
	/* no description */
#define DL_GA_ELEM_DY 186
	/* no description */
#define DL_GA_ELEM_HO 187
	/* no description */
#define DL_GA_ELEM_ER 188
	/* no description */
#define DL_GA_ELEM_TM 189
	/* no description */
#define DL_GA_ELEM_YB 190
	/* no description */
#define DL_GA_ELEM_LU 191
	/* no description */
#define DL_GA_ELEM_TH 192
	/* no description */
#define DL_GA_ELEM_PA 193
	/* no description */
#define DL_GA_ELEM_U 194
	/* no description */
#define DL_GA_ELEM_NP 195
	/* no description */
#define DL_GA_ELEM_PU 196
	/* no description */
#define DL_GA_ELEM_AM 197
	/* no description */
#define DL_GA_ELEM_CM 198
	/* no description */
#define DL_GA_ELEM_BK 199
	/* no description */
#define DL_GA_ELEM_CF 200
	/* no description */
#define DL_GA_ELEM_ES 201
	/* no description */
#define DL_GA_ELEM_FM 202
	/* no description */
#define DL_GA_ELEM_MD 203
	/* no description */
#define DL_GA_ELEM_NO 204
	/* no description */
#define DL_GA_ELEM_LR 205
	/* no description */
%endif
